@@ -87,7 +87,7 @@ Examples:
 
 	cmdconfig.
 		OnCmd(cmd).
-		AddBoolFlag(constants.ArgHelp, "h", false, "Help for plugin install")
+		AddBoolFlag(constants.ArgHelp, false, "Help for plugin install", cmdconfig.FlagOptions.WithShortHand("h"))
 	return cmd
 }
 
@@ -116,8 +116,8 @@ Examples:
 
 	cmdconfig.
 		OnCmd(cmd).
-		AddBoolFlag(constants.ArgAll, "", false, "Update all plugins to its latest available version").
-		AddBoolFlag(constants.ArgHelp, "h", false, "Help for plugin update")
+		AddBoolFlag(constants.ArgAll, false, "Update all plugins to its latest available version").
+		AddBoolFlag(constants.ArgHelp, false, "Help for plugin update", cmdconfig.FlagOptions.WithShortHand("h"))
 
 	return cmd
 }
@@ -144,8 +144,8 @@ Examples:
 
 	cmdconfig.
 		OnCmd(cmd).
-		AddBoolFlag("outdated", "", false, "Check each plugin in the list for updates").
-		AddBoolFlag(constants.ArgHelp, "h", false, "Help for plugin list")
+		AddBoolFlag("outdated", false, "Check each plugin in the list for updates").
+		AddBoolFlag(constants.ArgHelp, false, "Help for plugin list", cmdconfig.FlagOptions.WithShortHand("h"))
 
 	return cmd
 }
@@ -172,7 +172,7 @@ Example:
 	}
 
 	cmdconfig.OnCmd(cmd).
-		AddBoolFlag(constants.ArgHelp, "h", false, "Help for plugin uninstall")
+		AddBoolFlag(constants.ArgHelp, false, "Help for plugin uninstall", cmdconfig.FlagOptions.WithShortHand("h"))
 
 	return cmd
 }
@@ -209,7 +209,7 @@ func runPluginInstallCmd(cmd *cobra.Command, args []string) {
 		fmt.Println()
 		cmd.Help()
 		fmt.Println()
-		exitCode = constants.ExitCodeInsufficientOrWrongArguments
+		exitCode = constants.ExitCodeInsufficientOrWrongInputs
 		return
 	}
 
@@ -255,7 +255,7 @@ func doPluginInstall(ctx context.Context, bar *uiprogress.Bar, pluginName string
 		bar.Set(len(pluginInstallSteps))
 		// let the bar append itself with "Already Installed"
 		bar.AppendFunc(func(b *uiprogress.Bar) string {
-			return utils.Resize(constants.PluginAlreadyInstalled, 20)
+			return helpers.Resize(constants.PluginAlreadyInstalled, 20)
 		})
 		report = &display.PluginInstallReport{
 			Plugin:         pluginName,
@@ -267,13 +267,13 @@ func doPluginInstall(ctx context.Context, bar *uiprogress.Bar, pluginName string
 		// let the bar append itself with the current installation step
 		bar.AppendFunc(func(b *uiprogress.Bar) string {
 			if report != nil && report.SkipReason == constants.PluginNotFound {
-				return utils.Resize(constants.PluginNotFound, 20)
+				return helpers.Resize(constants.PluginNotFound, 20)
 			} else {
 				if b.Current() == 0 {
 					// no install step to display yet
 					return ""
 				}
-				return utils.Resize(pluginInstallSteps[b.Current()-1], 20)
+				return helpers.Resize(pluginInstallSteps[b.Current()-1], 20)
 			}
 		})
 		report = installPlugin(ctx, pluginName, false, bar)
@@ -303,13 +303,14 @@ func runPluginUpdateCmd(cmd *cobra.Command, args []string) {
 		fmt.Println()
 		cmd.Help()
 		fmt.Println()
-		exitCode = constants.ExitCodeInsufficientOrWrongArguments
+		exitCode = constants.ExitCodeInsufficientOrWrongInputs
 		return
 	}
 
 	if len(plugins) > 0 && !(cmdconfig.Viper().GetBool("all")) && plugins[0] == "all" {
 		// improve the response to wrong argument "steampipe plugin update all"
 		fmt.Println()
+		exitCode = constants.ExitCodeInsufficientOrWrongInputs
 		error_helpers.ShowError(ctx, fmt.Errorf("Did you mean %s?", constants.Bold("--all")))
 		fmt.Println()
 		return
@@ -318,7 +319,7 @@ func runPluginUpdateCmd(cmd *cobra.Command, args []string) {
 	state, err := statefile.LoadState()
 	if err != nil {
 		error_helpers.ShowError(ctx, fmt.Errorf("could not load state"))
-		exitCode = constants.ExitCodeLoadingError
+		exitCode = constants.ExitCodePluginLoadingError
 		return
 	}
 
@@ -326,7 +327,7 @@ func runPluginUpdateCmd(cmd *cobra.Command, args []string) {
 	versionData, err := versionfile.LoadPluginVersionFile()
 	if err != nil {
 		error_helpers.ShowError(ctx, fmt.Errorf("error loading current plugin data"))
-		exitCode = constants.ExitCodeLoadingError
+		exitCode = constants.ExitCodePluginLoadingError
 		return
 	}
 
@@ -353,6 +354,7 @@ func runPluginUpdateCmd(cmd *cobra.Command, args []string) {
 			if isExists {
 				runUpdatesFor = append(runUpdatesFor, versionData.Plugins[ref.DisplayImageRef()])
 			} else {
+				exitCode = constants.ExitCodePluginNotFound
 				updateResults = append(updateResults, &display.PluginInstallReport{
 					Skipped:        true,
 					Plugin:         p,
@@ -372,16 +374,18 @@ func runPluginUpdateCmd(cmd *cobra.Command, args []string) {
 		return
 	}
 	statusSpinner := statushooks.NewStatusSpinner(statushooks.WithMessage("Checking for available updates"))
-	// long timeout - we are happy to wait
-	timeout := 30 * time.Second
-	reports := plugin.GetUpdateReport(state.InstallationID, runUpdatesFor, timeout)
+
+	timeoutCtx, cancel := context.WithTimeout(cmd.Context(), 30*time.Second)
+	defer cancel()
+
+	reports := plugin.GetUpdateReport(timeoutCtx, state.InstallationID, runUpdatesFor)
 	statusSpinner.Done()
 
 	if len(reports) == 0 {
 		// this happens if for some reason the update server could not be contacted,
 		// in which case we get back an empty map
 		error_helpers.ShowError(ctx, fmt.Errorf("there was an issue contacting the update server, please try later"))
-		exitCode = constants.ExitCodeLoadingError
+		exitCode = constants.ExitCodePluginLoadingError
 		return
 	}
 
@@ -421,7 +425,7 @@ func doPluginUpdate(ctx context.Context, bar *uiprogress.Bar, pvr plugin.Version
 	if skip, skipReason := plugin.SkipUpdate(pvr); skip {
 		bar.AppendFunc(func(b *uiprogress.Bar) string {
 			// set the progress bar to append itself with "Already Installed"
-			return utils.Resize(skipReason, 30)
+			return helpers.Resize(skipReason, 30)
 		})
 		// set the progress bar to the maximum
 		bar.Set(len(pluginInstallSteps))
@@ -438,7 +442,7 @@ func doPluginUpdate(ctx context.Context, bar *uiprogress.Bar, pvr plugin.Version
 				// no install step to display yet
 				return ""
 			}
-			return utils.Resize(pluginInstallSteps[b.Current()-1], 20)
+			return helpers.Resize(pluginInstallSteps[b.Current()-1], 20)
 		})
 		report = installPlugin(ctx, pvr.Plugin.Name, true, bar)
 	}
@@ -449,7 +453,7 @@ func doPluginUpdate(ctx context.Context, bar *uiprogress.Bar, pvr plugin.Version
 func createProgressBar(plugin string, parentProgressBars *uiprogress.Progress) *uiprogress.Bar {
 	bar := parentProgressBars.AddBar(len(pluginInstallSteps))
 	bar.PrependFunc(func(b *uiprogress.Bar) string {
-		return utils.Resize(plugin, 20)
+		return helpers.Resize(plugin, 20)
 	})
 	return bar
 }
@@ -475,6 +479,7 @@ func installPlugin(ctx context.Context, pluginName string, isUpdate bool, bar *u
 		msg := ""
 		_, name, stream := ociinstaller.NewSteampipeImageRef(pluginName).GetOrgNameAndStream()
 		if isPluginNotFoundErr(err) {
+			exitCode = constants.ExitCodePluginNotFound
 			msg = constants.PluginNotFound
 		} else {
 			msg = err.Error()
@@ -650,7 +655,7 @@ func runPluginUninstallCmd(cmd *cobra.Command, args []string) {
 		fmt.Println()
 		cmd.Help()
 		fmt.Println()
-		exitCode = constants.ExitCodeInsufficientOrWrongArguments
+		exitCode = constants.ExitCodeInsufficientOrWrongInputs
 		return
 	}
 
@@ -666,6 +671,9 @@ func runPluginUninstallCmd(cmd *cobra.Command, args []string) {
 	for _, p := range args {
 		spinner.SetStatus(fmt.Sprintf("Uninstalling %s", p))
 		if report, err := plugin.Remove(ctx, p, connectionMap); err != nil {
+			if strings.Contains(err.Error(), "not found") {
+				exitCode = constants.ExitCodePluginNotFound
+			}
 			error_helpers.ShowErrorWithMessage(ctx, err, fmt.Sprintf("Failed to uninstall plugin '%s'", p))
 		} else {
 			report.ShortName = p
