@@ -3,7 +3,6 @@ package cmd
 import (
 	"context"
 	"fmt"
-	"github.com/turbot/steampipe/pkg/cloud"
 	"log"
 	"os"
 	"runtime/debug"
@@ -16,8 +15,9 @@ import (
 	"github.com/spf13/viper"
 	filehelpers "github.com/turbot/go-kit/files"
 	"github.com/turbot/go-kit/helpers"
-	"github.com/turbot/steampipe-plugin-sdk/v4/logging"
-	"github.com/turbot/steampipe-plugin-sdk/v4/plugin"
+	"github.com/turbot/steampipe-plugin-sdk/v5/logging"
+	"github.com/turbot/steampipe-plugin-sdk/v5/plugin"
+	"github.com/turbot/steampipe/pkg/cloud"
 	"github.com/turbot/steampipe/pkg/cmdconfig"
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/error_helpers"
@@ -33,11 +33,27 @@ import (
 )
 
 var exitCode int
+var waitForTasksChannel chan struct{}
+var tasksCancelFn context.CancelFunc
 
 // rootCmd represents the base command when called without any subcommands
 var rootCmd = &cobra.Command{
 	Use:     "steampipe [--version] [--help] COMMAND [args]",
 	Version: version.SteampipeVersion.String(),
+	PersistentPostRun: func(cmd *cobra.Command, args []string) {
+		utils.LogTime("cmd.PersistentPostRun start")
+		defer utils.LogTime("cmd.PersistentPostRun end")
+		if waitForTasksChannel != nil {
+			// wait for the async tasks to finish
+			select {
+			case <-time.After(100 * time.Millisecond):
+				tasksCancelFn()
+				return
+			case <-waitForTasksChannel:
+				return
+			}
+		}
+	},
 	PersistentPreRun: func(cmd *cobra.Command, args []string) {
 		utils.LogTime("cmd.root.PersistentPreRun start")
 		defer utils.LogTime("cmd.root.PersistentPreRun end")
@@ -50,9 +66,22 @@ var rootCmd = &cobra.Command{
 
 		createLogger()
 
+		// set up the global viper config with default values from
+		// config files and ENV variables
 		initGlobalConfig()
 
-		task.RunTasks()
+		var taskUpdateCtx context.Context
+		taskUpdateCtx, tasksCancelFn = context.WithCancel(cmd.Context())
+
+		waitForTasksChannel = task.RunTasks(
+			taskUpdateCtx,
+			cmd,
+			args,
+			// pass the config value in rather than runRasks querying viper directly - to avoid concurrent map access issues
+			// (we can use the update-check viper config here, since initGlobalConfig has already set it up
+			// with values from the config files and ENV settings - update-check cannot be set from the command line)
+			task.WithUpdateCheck(viper.GetBool(constants.ArgUpdateCheck)),
+		)
 
 		// set the max memory
 		debug.SetMemoryLimit(plugin.GetMaxMemoryBytes())
