@@ -58,30 +58,30 @@ connection from any Postgres compatible database client.`,
 
 	cmdconfig.
 		OnCmd(cmd).
-		AddBoolFlag(constants.ArgHelp, "h", false, "Help for service start").
+		AddBoolFlag(constants.ArgHelp, false, "Help for service start", cmdconfig.FlagOptions.WithShortHand("h")).
 		// for now default port to -1 so we fall back to the default of the deprecated arg
-		AddIntFlag(constants.ArgDatabasePort, "", constants.DatabaseDefaultPort, "Database service port").
+		AddIntFlag(constants.ArgDatabasePort, constants.DatabaseDefaultPort, "Database service port").
 		// for now default listen address to empty so we fall back to the default of the deprecated arg
-		AddStringFlag(constants.ArgListenAddress, "", string(db_local.ListenTypeNetwork), "Accept connections from: local (localhost only) or network (open) (postgres)").
-		AddStringFlag(constants.ArgServicePassword, "", "", "Set the database password for this session").
+		AddStringFlag(constants.ArgListenAddress, string(db_local.ListenTypeNetwork), "Accept connections from: local (localhost only) or network (open) (postgres)").
+		AddStringFlag(constants.ArgServicePassword, "", "Set the database password for this session").
 		// default is false and hides the database user password from service start prompt
-		AddBoolFlag(constants.ArgServiceShowPassword, "", false, "View database password for connecting from another machine").
+		AddBoolFlag(constants.ArgServiceShowPassword, false, "View database password for connecting from another machine").
 		// dashboard server
-		AddBoolFlag(constants.ArgDashboard, "", false, "Run the dashboard webserver with the service").
-		AddStringFlag(constants.ArgDashboardListen, "", string(dashboardserver.ListenTypeNetwork), "Accept connections from: local (localhost only) or network (open) (dashboard)").
-		AddIntFlag(constants.ArgDashboardPort, "", constants.DashboardServerDefaultPort, "Report server port").
+		AddBoolFlag(constants.ArgDashboard, false, "Run the dashboard webserver with the service").
+		AddStringFlag(constants.ArgDashboardListen, string(dashboardserver.ListenTypeNetwork), "Accept connections from: local (localhost only) or network (open) (dashboard)").
+		AddIntFlag(constants.ArgDashboardPort, constants.DashboardServerDefaultPort, "Report server port").
 		// foreground enables the service to run in the foreground - till exit
-		AddBoolFlag(constants.ArgForeground, "", false, "Run the service in the foreground").
+		AddBoolFlag(constants.ArgForeground, false, "Run the service in the foreground").
 
 		// flags relevant only if the --dashboard arg is used:
-		AddStringSliceFlag(constants.ArgVarFile, "", nil, "Specify an .spvar file containing variable values (only applies if '--dashboard' flag is also set)").
+		AddStringSliceFlag(constants.ArgVarFile, nil, "Specify an .spvar file containing variable values (only applies if '--dashboard' flag is also set)").
 		// NOTE: use StringArrayFlag for ArgVariable, not StringSliceFlag
 		// Cobra will interpret values passed to a StringSliceFlag as CSV,
 		// where args passed to StringArrayFlag are not parsed and used raw
-		AddStringArrayFlag(constants.ArgVariable, "", nil, "Specify the value of a variable (only applies if '--dashboard' flag is also set)").
+		AddStringArrayFlag(constants.ArgVariable, nil, "Specify the value of a variable (only applies if '--dashboard' flag is also set)").
 
 		// hidden flags for internal use
-		AddStringFlag(constants.ArgInvoker, "", string(constants.InvokerService), "Invoked by \"service\" or \"query\"", cmdconfig.FlagOptions.Hidden())
+		AddStringFlag(constants.ArgInvoker, string(constants.InvokerService), "Invoked by \"service\" or \"query\"", cmdconfig.FlagOptions.Hidden())
 
 	return cmd
 }
@@ -99,10 +99,10 @@ Report current status of the Steampipe database service.`,
 	}
 
 	cmdconfig.OnCmd(cmd).
-		AddBoolFlag(constants.ArgHelp, "h", false, "Help for service status").
+		AddBoolFlag(constants.ArgHelp, false, "Help for service status", cmdconfig.FlagOptions.WithShortHand("h")).
 		// default is false and hides the database user password from service start prompt
-		AddBoolFlag(constants.ArgServiceShowPassword, "", false, "View database password for connecting from another machine").
-		AddBoolFlag(constants.ArgAll, "", false, "Bypasses the INSTALL_DIR and reports status of all running steampipe services")
+		AddBoolFlag(constants.ArgServiceShowPassword, false, "View database password for connecting from another machine").
+		AddBoolFlag(constants.ArgAll, false, "Bypasses the INSTALL_DIR and reports status of all running steampipe services")
 
 	return cmd
 }
@@ -119,8 +119,8 @@ func serviceStopCmd() *cobra.Command {
 
 	cmdconfig.
 		OnCmd(cmd).
-		AddBoolFlag(constants.ArgHelp, "h", false, "Help for service stop").
-		AddBoolFlag(constants.ArgForce, "", false, "Forces all services to shutdown, releasing all open connections and ports")
+		AddBoolFlag(constants.ArgHelp, false, "Help for service stop", cmdconfig.FlagOptions.WithShortHand("h")).
+		AddBoolFlag(constants.ArgForce, false, "Forces all services to shutdown, releasing all open connections and ports")
 
 	return cmd
 }
@@ -137,8 +137,8 @@ func serviceRestartCmd() *cobra.Command {
 
 	cmdconfig.
 		OnCmd(cmd).
-		AddBoolFlag(constants.ArgHelp, "h", false, "Help for service restart").
-		AddBoolFlag(constants.ArgForce, "", false, "Forces the service to restart, releasing all open connections and ports")
+		AddBoolFlag(constants.ArgHelp, false, "Help for service restart", cmdconfig.FlagOptions.WithShortHand("h")).
+		AddBoolFlag(constants.ArgForce, false, "Forces the service to restart, releasing all open connections and ports")
 
 	return cmd
 }
@@ -164,24 +164,38 @@ func runServiceStartCmd(cmd *cobra.Command, args []string) {
 
 	port := viper.GetInt(constants.ArgDatabasePort)
 	if port < 1 || port > 65535 {
+		exitCode = constants.ExitCodeInsufficientOrWrongInputs
 		panic("Invalid port - must be within range (1:65535)")
 	}
 
 	serviceListen := db_local.StartListenType(viper.GetString(constants.ArgListenAddress))
-	error_helpers.FailOnError(serviceListen.IsValid())
+	if serviceListen.IsValid() != nil {
+		exitCode = constants.ExitCodeInsufficientOrWrongInputs
+		error_helpers.FailOnError(serviceListen.IsValid())
+	}
 
 	invoker := constants.Invoker(cmdconfig.Viper().GetString(constants.ArgInvoker))
-	error_helpers.FailOnError(invoker.IsValid())
+	if invoker.IsValid() != nil {
+		exitCode = constants.ExitCodeInsufficientOrWrongInputs
+		error_helpers.FailOnError(invoker.IsValid())
+	}
 
 	err := db_local.EnsureDBInstalled(ctx)
-	error_helpers.FailOnError(err)
+	if err != nil {
+		exitCode = constants.ExitCodeServiceStartupFailure
+		error_helpers.FailOnError(err)
+	}
 
 	// start db, refreshing connections
 	startResult := db_local.StartServices(ctx, port, serviceListen, invoker)
-	error_helpers.FailOnError(startResult.Error)
+	if startResult.Error != nil {
+		exitCode = constants.ExitCodeServiceSetupFailure
+		error_helpers.FailOnError(startResult.Error)
+	}
 
 	if startResult.Status == db_local.ServiceFailedToStart {
 		error_helpers.ShowError(ctx, fmt.Errorf("steampipe service failed to start"))
+		exitCode = constants.ExitCodeServiceStartupFailure
 		return
 	}
 
@@ -189,9 +203,11 @@ func runServiceStartCmd(cmd *cobra.Command, args []string) {
 
 		// check that we have the same port and listen parameters
 		if port != startResult.DbState.Port {
+			exitCode = constants.ExitCodeInsufficientOrWrongInputs
 			error_helpers.FailOnError(fmt.Errorf("service is already running on port %d - cannot change port while it's running", startResult.DbState.Port))
 		}
 		if serviceListen != startResult.DbState.ListenType {
+			exitCode = constants.ExitCodeInsufficientOrWrongInputs
 			error_helpers.FailOnError(fmt.Errorf("service is already running and listening on %s - cannot change listen type while it's running", startResult.DbState.ListenType))
 		}
 
@@ -199,6 +215,7 @@ func runServiceStartCmd(cmd *cobra.Command, args []string) {
 		startResult.DbState.Invoker = constants.InvokerService
 		err = startResult.DbState.Save()
 		if err != nil {
+			exitCode = constants.ExitCodeFileSystemAccessFailure
 			error_helpers.FailOnErrorWithMessage(err, "service was already running, but could not make it persistent")
 		}
 	}
@@ -211,6 +228,7 @@ func runServiceStartCmd(cmd *cobra.Command, args []string) {
 			_, err1 := db_local.StopServices(ctx, false, constants.InvokerService)
 			if err1 != nil {
 				error_helpers.ShowError(ctx, err1)
+				exitCode = constants.ExitCodeServiceSetupFailure
 			}
 			error_helpers.FailOnError(err)
 		}
@@ -317,7 +335,7 @@ func runServiceInForeground(ctx context.Context, invoker constants.Invoker) {
 			dashboardserver.StopDashboardService(ctx)
 			// if we have received this signal, then the user probably wants to shut down
 			// everything. Shutdowns MUST NOT happen in cancellable contexts
-			count, err := db_local.GetCountOfThirdPartyClients(context.Background())
+			connectedClients, err := db_local.GetClientCount(context.Background())
 			if err != nil {
 				// report the error in the off chance that there's one
 				error_helpers.ShowError(ctx, err)
@@ -325,7 +343,7 @@ func runServiceInForeground(ctx context.Context, invoker constants.Invoker) {
 			}
 
 			// we know there will be at least 1 client (connectionWatcher)
-			if count > 1 {
+			if connectedClients.TotalClients > 1 {
 				if lastCtrlC.IsZero() || time.Since(lastCtrlC) > 30*time.Second {
 					lastCtrlC = time.Now()
 					fmt.Println(buildForegroundClientsConnectedMsg())
@@ -373,7 +391,11 @@ func runServiceRestartCmd(cmd *cobra.Command, args []string) {
 
 	// stop db
 	stopStatus, err := db_local.StopServices(ctx, viper.GetBool(constants.ArgForce), constants.InvokerService)
-	error_helpers.FailOnErrorWithMessage(err, "could not stop current instance")
+	if err != nil {
+		exitCode = constants.ExitCodeServiceStopFailure
+		error_helpers.FailOnErrorWithMessage(err, "could not stop current instance")
+	}
+
 	if stopStatus != db_local.ServiceStopped {
 		fmt.Println(`
 Service stop failed.
@@ -388,7 +410,10 @@ to force a restart.
 
 	// stop the running dashboard server
 	err = dashboardserver.StopDashboardService(ctx)
-	error_helpers.FailOnErrorWithMessage(err, "could not stop dashboard service")
+	if err != nil {
+		exitCode = constants.ExitCodeServiceStopFailure
+		error_helpers.FailOnErrorWithMessage(err, "could not stop dashboard service")
+	}
 
 	// set the password in 'viper' so that it can be used by 'service start'
 	viper.Set(constants.ArgServicePassword, currentDbState.Password)
@@ -397,13 +422,17 @@ to force a restart.
 	dbStartResult := db_local.StartServices(cmd.Context(), currentDbState.Port, currentDbState.ListenType, currentDbState.Invoker)
 	error_helpers.FailOnError(dbStartResult.Error)
 	if dbStartResult.Status == db_local.ServiceFailedToStart {
+		exitCode = constants.ExitCodeServiceStartupFailure
 		fmt.Println("Steampipe service was stopped, but failed to restart.")
 		return
 	}
 
 	// refresh connections
 	err = db_local.RefreshConnectionAndSearchPaths(cmd.Context(), constants.InvokerService)
-	error_helpers.FailOnError(err)
+	if err != nil {
+		exitCode = constants.ExitCodeServiceSetupFailure
+		error_helpers.FailOnError(err)
+	}
 
 	// if the dashboard was running, start it
 	if currentDashboardState != nil {
@@ -488,13 +517,22 @@ func runServiceStopCmd(cmd *cobra.Command, args []string) {
 		dashboardStopError := dashboardserver.StopDashboardService(ctx)
 		status, dbStopError = db_local.StopServices(ctx, force, constants.InvokerService)
 		dbStopError = error_helpers.CombineErrors(dbStopError, dashboardStopError)
-		error_helpers.FailOnError(dbStopError)
+		if dbStopError != nil {
+			exitCode = constants.ExitCodeServiceStopFailure
+			error_helpers.FailOnError(dbStopError)
+		}
 	} else {
 		dbState, dbStopError = db_local.GetState()
-		error_helpers.FailOnErrorWithMessage(dbStopError, "could not stop Steampipe service")
+		if dbStopError != nil {
+			exitCode = constants.ExitCodeServiceStopFailure
+			error_helpers.FailOnErrorWithMessage(dbStopError, "could not stop Steampipe service")
+		}
 
 		dashboardState, err := dashboardserver.GetDashboardServiceState()
-		error_helpers.FailOnErrorWithMessage(err, "could not stop Steampipe service")
+		if err != nil {
+			exitCode = constants.ExitCodeServiceStopFailure
+			error_helpers.FailOnErrorWithMessage(err, "could not stop Steampipe service")
+		}
 
 		if dbState == nil {
 			fmt.Println("Steampipe service is not running.")
@@ -507,21 +545,29 @@ func runServiceStopCmd(cmd *cobra.Command, args []string) {
 
 		if dashboardState != nil {
 			err = dashboardserver.StopDashboardService(ctx)
-			error_helpers.FailOnErrorWithMessage(err, "could not stop dashboard server")
+			if err != nil {
+				exitCode = constants.ExitCodeServiceStopFailure
+				error_helpers.FailOnErrorWithMessage(err, "could not stop dashboard server")
+			}
 		}
 
-		var connectedClientCount int
 		// check if there are any connected clients to the service
-		connectedClientCount, err = db_local.GetCountOfThirdPartyClients(cmd.Context())
-		error_helpers.FailOnErrorWithMessage(err, "service stop failed")
+		connectedClients, err := db_local.GetClientCount(cmd.Context())
+		if err != nil {
+			exitCode = constants.ExitCodeServiceStopFailure
+			error_helpers.FailOnErrorWithMessage(err, "service stop failed")
+		}
 
-		if connectedClientCount > 0 {
+		if connectedClients.TotalClients > 0 {
 			printClientsConnected()
 			return
 		}
 
 		status, err = db_local.StopServices(ctx, false, constants.InvokerService)
-		error_helpers.FailOnErrorWithMessage(err, "service stop failed")
+		if err != nil {
+			exitCode = constants.ExitCodeServiceStopFailure
+			error_helpers.FailOnErrorWithMessage(err, "service stop failed")
+		}
 	}
 
 	switch status {
