@@ -14,15 +14,17 @@ type flagOpt func(c *cobra.Command, name string, key string)
 
 // FlagOptions :: shortcut for common flag options
 var FlagOptions = struct {
-	Required    func() flagOpt
-	Hidden      func() flagOpt
-	Deprecated  func(string) flagOpt
-	NoOptDefVal func(string) flagOpt
+	Required      func() flagOpt
+	Hidden        func() flagOpt
+	Deprecated    func(string) flagOpt
+	NoOptDefVal   func(string) flagOpt
+	WithShortHand func(string) flagOpt
 }{
-	Required:    requiredOpt,
-	Hidden:      hiddenOpt,
-	Deprecated:  deprecatedOpt,
-	NoOptDefVal: noOptDefValOpt,
+	Required:      requiredOpt,
+	Hidden:        hiddenOpt,
+	Deprecated:    deprecatedOpt,
+	NoOptDefVal:   noOptDefValOpt,
+	WithShortHand: withShortHand,
 }
 
 // Helper function to mark a flag as required
@@ -53,3 +55,9 @@ func noOptDefValOpt(noOptDefVal string) flagOpt {
 		c.Flag(name).NoOptDefVal = noOptDefVal
 	}
 }
+
+func withShortHand(shorthand string) flagOpt {
+	return func(c *cobra.Command, name, key string) {
+		c.Flag(name).Shorthand = shorthand
+	}
+}
