@@ -2,23 +2,23 @@ package connectionwatcher
 
 import (
 	"context"
+	"log"
+
 	"github.com/fsnotify/fsnotify"
 	filehelpers "github.com/turbot/go-kit/files"
 	"github.com/turbot/go-kit/filewatcher"
 	"github.com/turbot/go-kit/helpers"
-	sdkproto "github.com/turbot/steampipe-plugin-sdk/v4/grpc/proto"
+	sdkproto "github.com/turbot/steampipe-plugin-sdk/v5/grpc/proto"
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/db/db_local"
 	"github.com/turbot/steampipe/pkg/filepaths"
 	"github.com/turbot/steampipe/pkg/steampipeconfig"
-	"log"
 )
 
 type ConnectionWatcher struct {
 	fileWatcherErrorHandler   func(error)
 	watcher                   *filewatcher.FileWatcher
 	onConnectionConfigChanged func(configMap map[string]*sdkproto.ConnectionConfig)
-	count                     int
 }
 
 func NewConnectionWatcher(onConnectionChanged func(configMap map[string]*sdkproto.ConnectionConfig)) (*ConnectionWatcher, error) {
@@ -30,6 +30,7 @@ func NewConnectionWatcher(onConnectionChanged func(configMap map[string]*sdkprot
 		Directories: []string{filepaths.EnsureConfigDir()},
 		Include:     filehelpers.InclusionsFromExtensions([]string{constants.ConfigExtension}),
 		ListFlag:    filehelpers.FilesRecursive,
+		EventMask:   fsnotify.Create | fsnotify.Remove | fsnotify.Rename | fsnotify.Write,
 		OnChange: func(events []fsnotify.Event) {
 			w.handleFileWatcherEvent(events)
 		},
@@ -52,7 +53,7 @@ func NewConnectionWatcher(onConnectionChanged func(configMap map[string]*sdkprot
 	return w, nil
 }
 
-func (w *ConnectionWatcher) handleFileWatcherEvent(e []fsnotify.Event) {
+func (w *ConnectionWatcher) handleFileWatcherEvent(_ []fsnotify.Event) {
 	defer func() {
 		if r := recover(); r != nil {
 			log.Printf("[WARN] ConnectionWatcher caught a panic: %s", helpers.ToError(r).Error())
@@ -62,14 +63,6 @@ func (w *ConnectionWatcher) handleFileWatcherEvent(e []fsnotify.Event) {
 	// this is a file system event handler and not bound to any context
 	ctx := context.Background()
 
-	// ignore the first event - this is raised as soon as we start the watcher
-	// (this is to avoid conflicting calls to refreshConnections between Steampipe and the watcher)
-	w.count++
-	if w.count == 1 {
-		log.Printf("[TRACE] handleFileWatcherEvent ignoring first event")
-		return
-	}
-
 	log.Printf("[TRACE] ConnectionWatcher handleFileWatcherEvent")
 	config, err := steampipeconfig.LoadConnectionConfig()
 	if err != nil {
