@@ -4,11 +4,11 @@ import (
 	"fmt"
 	"time"
 
+	"github.com/turbot/go-kit/helpers"
 	"github.com/turbot/steampipe/pkg/constants"
-	"github.com/turbot/steampipe/pkg/utils"
 )
 
 var (
-	ExecutionID     = utils.GetMD5Hash(fmt.Sprintf("%d", time.Now().Nanosecond()))[:4]
+	ExecutionID     = helpers.GetMD5Hash(fmt.Sprintf("%d", time.Now().Nanosecond()))[:4]
 	PgClientAppName = fmt.Sprintf("%s_%s", constants.AppName, ExecutionID)
 )
