@@ -4,12 +4,11 @@ import (
 	"context"
 	"fmt"
 	"log"
-	"strings"
 	"sync"
 	"time"
 
 	typehelpers "github.com/turbot/go-kit/types"
-	"github.com/turbot/steampipe-plugin-sdk/v4/grpc"
+	"github.com/turbot/steampipe-plugin-sdk/v5/grpc"
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/control/controlstatus"
 	"github.com/turbot/steampipe/pkg/dashboard/dashboardtypes"
@@ -42,8 +41,8 @@ type ControlRun struct {
 	// the control being run
 	Control *modconfig.Control `json:"properties,omitempty"`
 	// control summary
-	Summary   *controlstatus.StatusSummary   `json:"summary"`
-	RunStatus controlstatus.ControlRunStatus `json:"status"`
+	Summary   *controlstatus.StatusSummary `json:"summary"`
+	RunStatus dashboardtypes.RunStatus     `json:"status"`
 	// result rows
 	Rows ResultRows `json:"-"`
 
@@ -93,7 +92,7 @@ func NewControlRun(control *modconfig.Control, group *ResultGroup, executionTree
 		rowMap:    make(map[string]ResultRows),
 		Summary:   &controlstatus.StatusSummary{},
 		Tree:      executionTree,
-		RunStatus: controlstatus.ControlRunReady,
+		RunStatus: dashboardtypes.RunInitialized,
 
 		Group:    group,
 		NodeType: modconfig.BlockTypeControl,
@@ -110,7 +109,7 @@ func (r *ControlRun) GetControlId() string {
 }
 
 // GetRunStatus implements ControlRunStatusProvider
-func (r *ControlRun) GetRunStatus() controlstatus.ControlRunStatus {
+func (r *ControlRun) GetRunStatus() dashboardtypes.RunStatus {
 	r.stateLock.Lock()
 	defer r.stateLock.Unlock()
 	return r.RunStatus
@@ -125,7 +124,7 @@ func (r *ControlRun) GetStatusSummary() *controlstatus.StatusSummary {
 
 func (r *ControlRun) Finished() bool {
 	status := r.GetRunStatus()
-	return status == controlstatus.ControlRunComplete || status == controlstatus.ControlRunError
+	return status == dashboardtypes.RunComplete || status.IsError()
 }
 
 // MatchTag returns the value corresponding to the input key. Returns 'false' if not found
@@ -171,40 +170,15 @@ func (r *ControlRun) setError(ctx context.Context, err error) {
 	r.RunErrorString = r.runError.Error()
 	// update error count
 	r.Summary.Error++
-	r.setRunStatus(ctx, controlstatus.ControlRunError)
+	if error_helpers.IsContextCancelledError(err) {
+		r.setRunStatus(ctx, dashboardtypes.RunCanceled)
+	} else {
+		r.setRunStatus(ctx, dashboardtypes.RunError)
+	}
 }
 
 func (r *ControlRun) skip(ctx context.Context) {
-	r.setRunStatus(ctx, controlstatus.ControlRunComplete)
-}
-
-// set search path for this control run
-func (r *ControlRun) setSearchPath(ctx context.Context, session *db_common.DatabaseSession, client db_common.Client) error {
-	utils.LogTime("ControlRun.setSearchPath start")
-	defer utils.LogTime("ControlRun.setSearchPath end")
-
-	var searchPath []string
-	var searchPathPrefix []string
-
-	if r.Control.SearchPath == nil && r.Control.SearchPathPrefix == nil {
-		return nil
-	}
-	if r.Control.SearchPath != nil {
-		searchPath = strings.Split(*r.Control.SearchPath, ",")
-	}
-	if r.Control.SearchPathPrefix != nil {
-		searchPathPrefix = strings.Split(*r.Control.SearchPathPrefix, ",")
-	}
-
-	newSearchPath, err := client.ContructSearchPath(ctx, searchPath, searchPathPrefix)
-	if err != nil {
-		return err
-	}
-
-	// no execute the SQL to actuall set the search path
-	q := fmt.Sprintf("set search_path to %s", strings.Join(newSearchPath, ","))
-	_, err = session.Connection.Exec(ctx, q)
-	return err
+	r.setRunStatus(ctx, dashboardtypes.RunComplete)
 }
 
 func (r *ControlRun) execute(ctx context.Context, client db_common.Client) {
@@ -247,17 +221,17 @@ func (r *ControlRun) execute(ctx context.Context, client db_common.Client) {
 	dbSession := sessionResult.Session
 	defer func() {
 		// do this in a closure, otherwise the argument will not get evaluated during calltime
-		dbSession.Close(utils.IsContextCancelled(ctx))
+		dbSession.Close(error_helpers.IsContextCanceled(ctx))
 	}()
 
 	// set our status
-	r.RunStatus = controlstatus.ControlRunStarted
+	r.RunStatus = dashboardtypes.RunRunning
 
 	// update the current running control in the Progress renderer
 	r.Tree.Progress.OnControlStart(ctx, r)
 	defer func() {
 		// update Progress
-		if r.GetRunStatus() == controlstatus.ControlRunError {
+		if r.GetRunStatus() == dashboardtypes.RunError {
 			r.Tree.Progress.OnControlError(ctx, r)
 		} else {
 			r.Tree.Progress.OnControlComplete(ctx, r)
@@ -265,24 +239,18 @@ func (r *ControlRun) execute(ctx context.Context, client db_common.Client) {
 	}()
 
 	// resolve the control query
-	query, err := r.resolveControlQuery(control)
+	resolvedQuery, err := r.resolveControlQuery(control)
 	if err != nil {
 		r.setError(ctx, err)
 		return
 	}
 
-	log.Printf("[TRACE] setting search path %s\n", control.Name())
-	if err := r.setSearchPath(ctx, dbSession, client); err != nil {
-		r.setError(ctx, err)
-		return
-	}
-
 	controlExecutionCtx := r.getControlQueryContext(ctx)
 
 	// execute the control query
 	// NOTE no need to pass an OnComplete callback - we are already closing our session after waiting for results
 	log.Printf("[TRACE] execute start for, %s\n", control.Name())
-	queryResult, err := client.ExecuteInSession(controlExecutionCtx, dbSession, query, nil)
+	queryResult, err := client.ExecuteInSession(controlExecutionCtx, dbSession, nil, resolvedQuery.ExecuteSQL, resolvedQuery.Args...)
 	log.Printf("[TRACE] execute finish for, %s\n", control.Name())
 
 	if err != nil {
@@ -334,15 +302,12 @@ func (r *ControlRun) getControlQueryContext(ctx context.Context) context.Context
 	return newCtx
 }
 
-func (r *ControlRun) resolveControlQuery(control *modconfig.Control) (string, error) {
+func (r *ControlRun) resolveControlQuery(control *modconfig.Control) (*modconfig.ResolvedQuery, error) {
 	resolvedQuery, err := r.Tree.Workspace.ResolveQueryFromQueryProvider(control, nil)
 	if err != nil {
-		return "", fmt.Errorf(`cannot run %s - failed to resolve query "%s": %s`, control.Name(), typehelpers.SafeString(control.SQL), err.Error())
+		return nil, fmt.Errorf(`cannot run %s - failed to resolve query "%s": %s`, control.Name(), typehelpers.SafeString(control.SQL), err.Error())
 	}
-	if resolvedQuery.ExecuteSQL == "" {
-		return "", fmt.Errorf(`cannot run %s - failed to resolve query "%s"`, control.Name(), typehelpers.SafeString(control.SQL))
-	}
-	return resolvedQuery.ExecuteSQL, nil
+	return resolvedQuery, nil
 }
 
 func (r *ControlRun) waitForResults(ctx context.Context) {
@@ -361,7 +326,7 @@ func (r *ControlRun) waitForResults(ctx context.Context) {
 			// nil row means control run is complete
 			if row == nil {
 				// nil row means we are done
-				r.setRunStatus(ctx, controlstatus.ControlRunComplete)
+				r.setRunStatus(ctx, dashboardtypes.RunComplete)
 				r.createdOrderedResultRows()
 				return
 			}
@@ -436,7 +401,7 @@ func (r *ControlRun) createdOrderedResultRows() {
 	}
 }
 
-func (r *ControlRun) setRunStatus(ctx context.Context, status controlstatus.ControlRunStatus) {
+func (r *ControlRun) setRunStatus(ctx context.Context, status dashboardtypes.RunStatus) {
 	r.stateLock.Lock()
 	r.RunStatus = status
 	r.stateLock.Unlock()
