@@ -3,11 +3,12 @@ package controlexecute
 import (
 	"context"
 	"fmt"
-	"github.com/turbot/go-kit/helpers"
 	"log"
 	"sort"
 	"time"
 
+	"github.com/turbot/go-kit/helpers"
+
 	"github.com/spf13/viper"
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/control/controlstatus"
@@ -30,7 +31,7 @@ type ExecutionTree struct {
 	Progress    *controlstatus.ControlProgress `json:"progress"`
 	// map of dimension property name to property value to color map
 	DimensionColorGenerator *DimensionColorGenerator `json:"-"`
-	// the current session search path (this may be overidden for specific controls)
+	// the current session search path
 	SearchPath []string             `json:"-"`
 	Workspace  *workspace.Workspace `json:"-"`
 	client     db_common.Client
@@ -86,7 +87,7 @@ func (e *ExecutionTree) AddControl(ctx context.Context, control *modconfig.Contr
 	}
 }
 
-func (e *ExecutionTree) Execute(ctx context.Context) int {
+func (e *ExecutionTree) Execute(ctx context.Context) controlstatus.StatusSummary {
 	log.Println("[TRACE]", "begin ExecutionTree.Execute")
 	defer log.Println("[TRACE]", "end ExecutionTree.Execute")
 	e.StartTime = time.Now()
@@ -113,13 +114,11 @@ func (e *ExecutionTree) Execute(ctx context.Context) int {
 		log.Printf("[WARN] timed out waiting for active runs to complete")
 	}
 
-	failures := e.Root.Summary.Status.Alarm + e.Root.Summary.Status.Error
-
 	// now build map of dimension property name to property value to color map
 	e.DimensionColorGenerator, _ = NewDimensionColorGenerator(4, 27)
 	e.DimensionColorGenerator.populate(e)
 
-	return failures
+	return e.Root.Summary.Status
 }
 
 func (e *ExecutionTree) waitForActiveRunsToComplete(ctx context.Context, parallelismLock *semaphore.Weighted, maxParallelGoRoutines int64) error {
@@ -170,15 +169,14 @@ func (e *ExecutionTree) getExecutionRootFromArg(arg string) (modconfig.ModTreeIt
 		// but NOT children which come from dependency mods
 
 		// to achieve this, use a  DirectChildrenModDecorator
-
-		return DirectChildrenModDecorator{e.Workspace.Mod}, nil
+		return &DirectChildrenModDecorator{Mod: e.Workspace.Mod}, nil
 	}
 
 	// if the arg is the name of one of the workspace dependendencies, wrap it in DirectChildrenModDecorator
 	// so we only execute _its_ direct children
 	for _, mod := range e.Workspace.Mods {
 		if mod.ShortName == arg {
-			return DirectChildrenModDecorator{mod}, nil
+			return &DirectChildrenModDecorator{Mod: mod}, nil
 		}
 	}
 
@@ -206,19 +204,19 @@ func (e *ExecutionTree) getExecutionRootFromArg(arg string) (modconfig.ModTreeIt
 // This is used to implement the 'where' control filtering
 func (e *ExecutionTree) getControlMapFromWhereClause(ctx context.Context, whereClause string) (map[string]bool, error) {
 	// query may either be a 'where' clause, or a named query
-	query, _, err := e.Workspace.ResolveQueryAndArgsFromSQLString(whereClause)
+	resolvedQuery, _, err := e.Workspace.ResolveQueryAndArgsFromSQLString(whereClause)
 	if err != nil {
 		return nil, err
 	}
 	// did we in fact resolve a named query, or just return the 'name' as the query
-	isNamedQuery := query != whereClause
+	isNamedQuery := resolvedQuery.ExecuteSQL != whereClause
 
 	// if the query is NOT a named query, we need to construct a full query by adding a select
 	if !isNamedQuery {
-		query = fmt.Sprintf("select resource_name from %s where %s", constants.IntrospectionTableControl, whereClause)
+		resolvedQuery.ExecuteSQL = fmt.Sprintf("select resource_name from %s where %s", constants.IntrospectionTableControl, whereClause)
 	}
 
-	res, err := e.client.ExecuteSync(ctx, query)
+	res, err := e.client.ExecuteSync(ctx, resolvedQuery.ExecuteSQL, resolvedQuery.Args...)
 	if err != nil {
 		return nil, err
 	}
