@@ -18,34 +18,32 @@ import (
 
 // DashboardExecutionTree is a structure representing the control result hierarchy
 type DashboardExecutionTree struct {
-	Root dashboardtypes.DashboardNodeRun
+	Root dashboardtypes.DashboardTreeRun
 
 	dashboardName string
 	sessionId     string
 	client        db_common.Client
-	runs          map[string]dashboardtypes.DashboardNodeRun
+	runs          map[string]dashboardtypes.DashboardTreeRun
 	workspace     *workspace.Workspace
-	runComplete   chan dashboardtypes.DashboardNodeRun
+	runComplete   chan dashboardtypes.DashboardTreeRun
 
-	inputLock sync.Mutex
-	// store subscribers as a map of maps for simple unsubscription
-	inputDataSubscriptions map[string]map[*chan bool]struct{}
-	cancel                 context.CancelFunc
-	inputValues            map[string]interface{}
-	id                     string
+	// map of subscribers to notify when an input value changes
+	cancel      context.CancelFunc
+	inputLock   sync.Mutex
+	inputValues map[string]any
+	id          string
 }
 
 func NewDashboardExecutionTree(rootName string, sessionId string, client db_common.Client, workspace *workspace.Workspace) (*DashboardExecutionTree, error) {
 	// now populate the DashboardExecutionTree
 	executionTree := &DashboardExecutionTree{
-		dashboardName:          rootName,
-		sessionId:              sessionId,
-		client:                 client,
-		runs:                   make(map[string]dashboardtypes.DashboardNodeRun),
-		workspace:              workspace,
-		runComplete:            make(chan dashboardtypes.DashboardNodeRun, 1),
-		inputDataSubscriptions: make(map[string]map[*chan bool]struct{}),
-		inputValues:            make(map[string]interface{}),
+		dashboardName: rootName,
+		sessionId:     sessionId,
+		client:        client,
+		runs:          make(map[string]dashboardtypes.DashboardTreeRun),
+		workspace:     workspace,
+		runComplete:   make(chan dashboardtypes.DashboardTreeRun, 1),
+		inputValues:   make(map[string]any),
 	}
 	executionTree.id = fmt.Sprintf("%p", executionTree)
 
@@ -59,7 +57,7 @@ func NewDashboardExecutionTree(rootName string, sessionId string, client db_comm
 	return executionTree, nil
 }
 
-func (e *DashboardExecutionTree) createRootItem(rootName string) (dashboardtypes.DashboardNodeRun, error) {
+func (e *DashboardExecutionTree) createRootItem(rootName string) (dashboardtypes.DashboardTreeRun, error) {
 	parsedName, err := modconfig.ParseResourceName(rootName)
 	if err != nil {
 		return nil, err
@@ -133,15 +131,22 @@ func (e *DashboardExecutionTree) Execute(ctx context.Context) {
 	// build map of those variables referenced by the dashboard run
 	referencedVariables := GetReferencedVariables(e.Root, e.workspace)
 
-	workspace.PublishDashboardEvent(&dashboardevents.ExecutionStarted{
+	immutablePanels, err := utils.JsonCloneToMap(panels)
+	if err != nil {
+		e.SetError(ctx, err)
+		return
+	}
+	workspace.PublishDashboardEvent(ctx, &dashboardevents.ExecutionStarted{
 		Root:        e.Root,
 		Session:     e.sessionId,
 		ExecutionId: e.id,
-		Panels:      panels,
+		Panels:      immutablePanels,
 		Inputs:      e.inputValues,
 		Variables:   referencedVariables,
+		StartTime:   startTime,
 	})
 	defer func() {
+
 		e := &dashboardevents.ExecutionComplete{
 			Root:        e.Root,
 			Session:     e.sessionId,
@@ -155,13 +160,13 @@ func (e *DashboardExecutionTree) Execute(ctx context.Context) {
 			StartTime:  startTime,
 			EndTime:    time.Now(),
 		}
-		workspace.PublishDashboardEvent(e)
+		workspace.PublishDashboardEvent(ctx, e)
 	}()
 
 	log.Println("[TRACE]", "begin DashboardExecutionTree.Execute")
 	defer log.Println("[TRACE]", "end DashboardExecutionTree.Execute")
 
-	if e.GetRunStatus() == dashboardtypes.DashboardRunComplete {
+	if e.GetRunStatus() == dashboardtypes.RunComplete {
 		// there must be no nodes to execute
 		log.Println("[TRACE]", "execution tree already complete")
 		return
@@ -172,7 +177,7 @@ func (e *DashboardExecutionTree) Execute(ctx context.Context) {
 }
 
 // GetRunStatus returns the stats of the Root run
-func (e *DashboardExecutionTree) GetRunStatus() dashboardtypes.DashboardRunStatus {
+func (e *DashboardExecutionTree) GetRunStatus() dashboardtypes.RunStatus {
 	return e.Root.GetRunStatus()
 }
 
@@ -181,28 +186,54 @@ func (e *DashboardExecutionTree) SetError(ctx context.Context, err error) {
 	e.Root.SetError(ctx, err)
 }
 
-// GetName implements DashboardNodeParent
-// use mod chort name - this will be the root name for all child runs
+// GetName implements DashboardParent
+// use mod short name - this will be the root name for all child runs
 func (e *DashboardExecutionTree) GetName() string {
 	return e.workspace.Mod.ShortName
 }
 
-func (e *DashboardExecutionTree) SetInputs(inputValues map[string]interface{}) {
+// GetParent implements DashboardTreeRun
+func (e *DashboardExecutionTree) GetParent() dashboardtypes.DashboardParent {
+	return nil
+}
+
+// GetNodeType implements DashboardTreeRun
+func (*DashboardExecutionTree) GetNodeType() string {
+	panic("should never call for DashboardExecutionTree")
+}
+
+func (e *DashboardExecutionTree) SetInputValues(inputValues map[string]any) {
+	log.Printf("[TRACE] SetInputValues")
+	e.inputLock.Lock()
+	defer e.inputLock.Unlock()
+
+	// we only support inputs if root is a dashboard (NOT a benchmark)
+	runtimeDependencyPublisher, ok := e.Root.(RuntimeDependencyPublisher)
+	if !ok {
+		// should never happen
+		log.Printf("[WARN] SetInputValues called but root Dashboard run is not a RuntimeDependencyPublisher: %s", e.Root.GetName())
+		return
+	}
+
 	for name, value := range inputValues {
+		log.Printf("[TRACE] DashboardExecutionTree SetInput %s = %v", name, value)
 		e.inputValues[name] = value
-		// now see if anyone needs to be notified about this input
-		e.notifyInputAvailable(name)
+		// publish runtime dependency
+		runtimeDependencyPublisher.PublishRuntimeDependencyValue(name, &dashboardtypes.ResolvedRuntimeDependencyValue{Value: value})
 	}
 }
 
-// ChildCompleteChan implements DashboardNodeParent
-func (e *DashboardExecutionTree) ChildCompleteChan() chan dashboardtypes.DashboardNodeRun {
+// ChildCompleteChan implements DashboardParent
+func (e *DashboardExecutionTree) ChildCompleteChan() chan dashboardtypes.DashboardTreeRun {
 	return e.runComplete
 }
 
+// ChildStatusChanged implements DashboardParent
+func (*DashboardExecutionTree) ChildStatusChanged(context.Context) {}
+
 func (e *DashboardExecutionTree) Cancel() {
 	// if we have not completed, and already have a cancel function - cancel
-	if e.GetRunStatus() != dashboardtypes.DashboardRunReady || e.cancel == nil {
+	if e.GetRunStatus() != dashboardtypes.RunInitialized || e.cancel == nil {
 		return
 	}
 	e.cancel()
@@ -213,89 +244,79 @@ func (e *DashboardExecutionTree) Cancel() {
 	}
 }
 
-func (e *DashboardExecutionTree) GetInputValue(name string) interface{} {
-	return e.inputValues[name]
-}
-
 func (e *DashboardExecutionTree) BuildSnapshotPanels() map[string]dashboardtypes.SnapshotPanel {
+	// just build from e.runs
 	res := map[string]dashboardtypes.SnapshotPanel{}
-	// if this node is a snapshot node, add to map
-	if snapshotNode, ok := e.Root.(dashboardtypes.SnapshotPanel); ok {
-		res[e.Root.GetName()] = snapshotNode
+
+	for name, run := range e.runs {
+		res[name] = run.(dashboardtypes.SnapshotPanel)
+		// special case handling for check runs
+		if checkRun, ok := run.(*CheckRun); ok {
+			checkRunChildren := checkRun.BuildSnapshotPanels(res)
+			for k, v := range checkRunChildren {
+				res[k] = v
+			}
+		}
 	}
-	return e.buildSnapshotPanelsUnder(e.Root, res)
+	return res
 }
 
-// RuntimeDependencies returns the runtime dependencies for all leaf nodes
-func (e *DashboardExecutionTree) RuntimeDependencies() []string {
+// InputRuntimeDependencies returns the names of all inputs which are runtime dependencies
+func (e *DashboardExecutionTree) InputRuntimeDependencies() []string {
 	var deps = map[string]struct{}{}
 	for _, r := range e.runs {
 		if leafRun, ok := r.(*LeafRun); ok {
-			for _, v := range leafRun.runtimeDependencies {
-				deps[v.dependency.SourceResource.GetUnqualifiedName()] = struct{}{}
+			for _, r := range leafRun.runtimeDependencies {
+				if r.Dependency.PropertyPath.ItemType == modconfig.BlockTypeInput {
+					deps[r.Dependency.SourceResourceName()] = struct{}{}
+				}
 			}
 		}
 	}
 	return maps.Keys(deps)
 }
 
-func (e *DashboardExecutionTree) waitForRuntimeDependency(ctx context.Context, dependency *modconfig.RuntimeDependency) error {
-	depChan := make(chan bool, 1)
-
-	e.subscribeToInput(dependency.SourceResource.GetUnqualifiedName(), &depChan)
-	defer e.unsubscribeToInput(dependency.SourceResource.GetUnqualifiedName(), &depChan)
-
-	select {
-	case <-ctx.Done():
-		return ctx.Err()
-	case <-depChan:
-		return nil
-	}
+// GetChildren implements DashboardParent
+func (e *DashboardExecutionTree) GetChildren() []dashboardtypes.DashboardTreeRun {
+	return []dashboardtypes.DashboardTreeRun{e.Root}
 }
 
-func (e *DashboardExecutionTree) subscribeToInput(inputName string, depChan *chan bool) {
-	e.inputLock.Lock()
-	defer e.inputLock.Unlock()
-	subscriptions := e.inputDataSubscriptions[inputName]
-	if subscriptions == nil {
-		subscriptions = make(map[*chan bool]struct{})
-	}
-	subscriptions[depChan] = struct{}{}
-	e.inputDataSubscriptions[inputName] = subscriptions
+// ChildrenComplete implements DashboardParent
+func (e *DashboardExecutionTree) ChildrenComplete() bool {
+	return e.Root.RunComplete()
 }
 
-func (e *DashboardExecutionTree) notifyInputAvailable(inputName string) {
-	e.inputLock.Lock()
-	defer e.inputLock.Unlock()
+// Tactical: Empty implementations of DashboardParent functions
+// TODO remove need for this
 
-	for c := range e.inputDataSubscriptions[inputName] {
-		*c <- true
-	}
+func (e *DashboardExecutionTree) Initialise(ctx context.Context) {
+	panic("should never call for DashboardExecutionTree")
 }
 
-// remove a subscriber from the map of subscribers for this input
-func (e *DashboardExecutionTree) unsubscribeToInput(inputName string, depChan *chan bool) {
-	e.inputLock.Lock()
-	defer e.inputLock.Unlock()
-
-	subscribers := e.inputDataSubscriptions[inputName]
-	if len(subscribers) == 0 {
-		return
-	}
-	delete(subscribers, depChan)
+func (e *DashboardExecutionTree) GetTitle() string {
+	panic("should never call for DashboardExecutionTree")
 }
 
-func (e *DashboardExecutionTree) buildSnapshotPanelsUnder(parent dashboardtypes.DashboardNodeRun, res map[string]dashboardtypes.SnapshotPanel) map[string]dashboardtypes.SnapshotPanel {
-	if checkRun, ok := parent.(*CheckRun); ok {
-		return checkRun.BuildSnapshotPanels(res)
-	}
-	for _, c := range parent.GetChildren() {
-		// if this node is a snapshot node, add to map
-		if snapshotNode, ok := c.(dashboardtypes.SnapshotPanel); ok {
-			res[c.GetName()] = snapshotNode
-		}
-		res = e.buildSnapshotPanelsUnder(c, res)
-	}
-
-	return res
+func (e *DashboardExecutionTree) GetError() error {
+	panic("should never call for DashboardExecutionTree")
+}
+
+func (e *DashboardExecutionTree) SetComplete(ctx context.Context) {
+	panic("should never call for DashboardExecutionTree")
+}
+
+func (e *DashboardExecutionTree) RunComplete() bool {
+	panic("should never call for DashboardExecutionTree")
+}
+
+func (e *DashboardExecutionTree) GetInputsDependingOn(s string) []string {
+	panic("should never call for DashboardExecutionTree")
+}
+
+func (*DashboardExecutionTree) AsTreeNode() *dashboardtypes.SnapshotTreeNode {
+	panic("should never call for DashboardExecutionTree")
+}
+
+func (*DashboardExecutionTree) GetResource() modconfig.DashboardLeafNode {
+	panic("should never call for DashboardExecutionTree")
 }
