@@ -8,6 +8,7 @@ import (
 	"os"
 	"strings"
 	"sync"
+	"time"
 
 	filehelpers "github.com/turbot/go-kit/files"
 	"github.com/turbot/steampipe/pkg/dashboard/dashboardevents"
@@ -36,7 +37,7 @@ func newDashboardExecutor() *DashboardExecutor {
 
 var Executor = newDashboardExecutor()
 
-func (e *DashboardExecutor) ExecuteDashboard(ctx context.Context, sessionId, dashboardName string, inputs map[string]interface{}, workspace *workspace.Workspace, client db_common.Client) (err error) {
+func (e *DashboardExecutor) ExecuteDashboard(ctx context.Context, sessionId, dashboardName string, inputs map[string]any, workspace *workspace.Workspace, client db_common.Client) (err error) {
 	var executionTree *DashboardExecutionTree
 	defer func() {
 		if err != nil && ctx.Err() != nil {
@@ -45,10 +46,11 @@ func (e *DashboardExecutor) ExecuteDashboard(ctx context.Context, sessionId, das
 		// if there was an error executing, send an ExecutionError event
 		if err != nil {
 			errorEvent := &dashboardevents.ExecutionError{
-				Error:   err,
-				Session: sessionId,
+				Error:     err,
+				Session:   sessionId,
+				Timestamp: time.Now(),
 			}
-			workspace.PublishDashboardEvent(errorEvent)
+			workspace.PublishDashboardEvent(ctx, errorEvent)
 		}
 	}()
 
@@ -72,7 +74,7 @@ func (e *DashboardExecutor) ExecuteDashboard(ctx context.Context, sessionId, das
 
 	// if inputs have been passed, set them first
 	if len(inputs) > 0 {
-		executionTree.SetInputs(inputs)
+		executionTree.SetInputValues(inputs)
 	}
 
 	go executionTree.Execute(ctx)
@@ -82,15 +84,15 @@ func (e *DashboardExecutor) ExecuteDashboard(ctx context.Context, sessionId, das
 
 // if inputs must be provided before execution (i.e. this is a batch dashboard execution),
 // verify all required inputs are provided
-func (e *DashboardExecutor) validateInputs(executionTree *DashboardExecutionTree, inputs map[string]interface{}) error {
+func (e *DashboardExecutor) validateInputs(executionTree *DashboardExecutionTree, inputs map[string]any) error {
 	if e.interactive {
 		// interactive dashboard execution - no need to validate
 		return nil
 	}
 	var missingInputs []string
-	for _, dep := range executionTree.RuntimeDependencies() {
-		if _, ok := inputs[dep]; !ok {
-			missingInputs = append(missingInputs, dep)
+	for _, inputName := range executionTree.InputRuntimeDependencies() {
+		if _, ok := inputs[inputName]; !ok {
+			missingInputs = append(missingInputs, inputName)
 		}
 	}
 	if missingCount := len(missingInputs); missingCount > 0 {
@@ -129,7 +131,7 @@ func (e *DashboardExecutor) LoadSnapshot(ctx context.Context, sessionId, snapsho
 	return snap, nil
 }
 
-func (e *DashboardExecutor) OnInputChanged(ctx context.Context, sessionId string, inputs map[string]interface{}, changedInput string) error {
+func (e *DashboardExecutor) OnInputChanged(ctx context.Context, sessionId string, inputs map[string]any, changedInput string) error {
 	// find the execution
 	executionTree, found := e.executions[sessionId]
 	if !found {
@@ -146,11 +148,11 @@ func (e *DashboardExecutor) OnInputChanged(ctx context.Context, sessionId string
 			Session:       executionTree.sessionId,
 			ExecutionId:   executionTree.id,
 		}
-		executionTree.workspace.PublishDashboardEvent(event)
+		executionTree.workspace.PublishDashboardEvent(ctx, event)
 	}
 	// if there are any dependent inputs, set their value to nil and send an event to the UI
 	// if the dashboard run is complete, just re-execute
-	if executionTree.GetRunStatus() == dashboardtypes.DashboardRunComplete || inputPrevValue != nil {
+	if executionTree.GetRunStatus() == dashboardtypes.RunComplete || inputPrevValue != nil {
 		return e.ExecuteDashboard(
 			ctx,
 			sessionId,
@@ -161,12 +163,12 @@ func (e *DashboardExecutor) OnInputChanged(ctx context.Context, sessionId string
 	}
 
 	// set the inputs
-	executionTree.SetInputs(inputs)
+	executionTree.SetInputValues(inputs)
 
 	return nil
 }
 
-func (e *DashboardExecutor) clearDependentInputs(root dashboardtypes.DashboardNodeRun, changedInput string, inputs map[string]interface{}) []string {
+func (e *DashboardExecutor) clearDependentInputs(root dashboardtypes.DashboardTreeRun, changedInput string, inputs map[string]any) []string {
 	dependentInputs := root.GetInputsDependingOn(changedInput)
 	clearedInputs := dependentInputs
 	if len(dependentInputs) > 0 {
