@@ -113,7 +113,7 @@ func (s *Server) HandleDashboardEvent(event dashboardevents.DashboardEvent) {
 		OutputWait(s.context, fmt.Sprintf("Dashboard execution started: %s", e.Root.GetName()))
 
 	case *dashboardevents.ExecutionError:
-		log.Println("[TRACE] execution error event", *e)
+		log.Println("[TRACE] execution error event")
 		payload, payloadError = buildExecutionErrorPayload(e)
 		if payloadError != nil {
 			return
@@ -123,7 +123,7 @@ func (s *Server) HandleDashboardEvent(event dashboardevents.DashboardEvent) {
 		OutputError(s.context, e.Error)
 
 	case *dashboardevents.ExecutionComplete:
-		log.Println("[TRACE] execution complete event", *e)
+		log.Println("[TRACE] execution complete event")
 		payload, payloadError = buildExecutionCompletePayload(e)
 		if payloadError != nil {
 			return
@@ -132,9 +132,6 @@ func (s *Server) HandleDashboardEvent(event dashboardevents.DashboardEvent) {
 		s.writePayloadToSession(e.Session, payload)
 		outputReady(s.context, fmt.Sprintf("Execution complete: %s", dashboardName))
 
-	case *dashboardevents.LeafNodeError:
-		log.Printf("[TRACE] LeafNodeError event session %s, node %s, error %v", e.Session, e.LeafNode.GetName(), e.Error)
-
 	case *dashboardevents.ControlComplete:
 		log.Printf("[TRACE] ControlComplete event session %s, control %s", e.Session, e.Control.GetControlId())
 		payload, payloadError = buildControlCompletePayload(e)
@@ -151,49 +148,54 @@ func (s *Server) HandleDashboardEvent(event dashboardevents.DashboardEvent) {
 		}
 		s.writePayloadToSession(e.Session, payload)
 
-	case *dashboardevents.LeafNodeComplete:
-		log.Printf("[TRACE] LeafNodeComplete event session %s, node %s", e.Session, e.LeafNode.GetName())
-		payload, payloadError = buildLeafNodeCompletePayload(e)
+	case *dashboardevents.LeafNodeUpdated:
+		payload, payloadError = buildLeafNodeUpdatedPayload(e)
 		if payloadError != nil {
 			return
 		}
 		s.writePayloadToSession(e.Session, payload)
 
 	case *dashboardevents.DashboardChanged:
-		log.Println("[TRACE] DashboardChanged event", *e)
+		log.Println("[TRACE] DashboardChanged event")
 		deletedDashboards := e.DeletedDashboards
 		newDashboards := e.NewDashboards
 
-		changedContainers := e.ChangedContainers
 		changedBenchmarks := e.ChangedBenchmarks
+		changedCategories := e.ChangedCategories
+		changedContainers := e.ChangedContainers
 		changedControls := e.ChangedControls
 		changedCards := e.ChangedCards
 		changedCharts := e.ChangedCharts
+		changedDashboards := e.ChangedDashboards
+		changedEdges := e.ChangedEdges
 		changedFlows := e.ChangedFlows
 		changedGraphs := e.ChangedGraphs
 		changedHierarchies := e.ChangedHierarchies
 		changedImages := e.ChangedImages
 		changedInputs := e.ChangedInputs
+		changedNodes := e.ChangedNodes
 		changedTables := e.ChangedTables
 		changedTexts := e.ChangedTexts
-		changedDashboards := e.ChangedDashboards
 
 		// If nothing has changed, ignore
 		if len(deletedDashboards) == 0 &&
 			len(newDashboards) == 0 &&
-			len(changedContainers) == 0 &&
 			len(changedBenchmarks) == 0 &&
+			len(changedCategories) == 0 &&
+			len(changedContainers) == 0 &&
 			len(changedControls) == 0 &&
 			len(changedCards) == 0 &&
 			len(changedCharts) == 0 &&
+			len(changedDashboards) == 0 &&
+			len(changedEdges) == 0 &&
 			len(changedFlows) == 0 &&
 			len(changedGraphs) == 0 &&
 			len(changedHierarchies) == 0 &&
 			len(changedImages) == 0 &&
 			len(changedInputs) == 0 &&
+			len(changedNodes) == 0 &&
 			len(changedTables) == 0 &&
-			len(changedTexts) == 0 &&
-			len(changedDashboards) == 0 {
+			len(changedTexts) == 0 {
 			return
 		}
 
@@ -211,16 +213,16 @@ func (s *Server) HandleDashboardEvent(event dashboardevents.DashboardEvent) {
 			_ = s.webSocket.Broadcast(payload)
 		}
 
-		var dashboardssBeingWatched []string
+		var dashboardsBeingWatched []string
 
 		dashboardClients := s.getDashboardClients()
 		for _, dashboardClientInfo := range dashboardClients {
 			dashboardName := typeHelpers.SafeString(dashboardClientInfo.Dashboard)
 			if dashboardClientInfo.Dashboard != nil {
-				if helpers.StringSliceContains(dashboardssBeingWatched, dashboardName) {
+				if helpers.StringSliceContains(dashboardsBeingWatched, dashboardName) {
 					continue
 				}
-				dashboardssBeingWatched = append(dashboardssBeingWatched, dashboardName)
+				dashboardsBeingWatched = append(dashboardsBeingWatched, dashboardName)
 			}
 		}
 
@@ -228,18 +230,21 @@ func (s *Server) HandleDashboardEvent(event dashboardevents.DashboardEvent) {
 		var newDashboardNames []string
 
 		// Process the changed items and make a note of the dashboard(s) they're in
-		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardssBeingWatched, changedDashboardNames, changedContainers)...)
-		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardssBeingWatched, changedDashboardNames, changedBenchmarks)...)
-		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardssBeingWatched, changedDashboardNames, changedControls)...)
-		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardssBeingWatched, changedDashboardNames, changedCards)...)
-		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardssBeingWatched, changedDashboardNames, changedCharts)...)
-		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardssBeingWatched, changedDashboardNames, changedFlows)...)
-		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardssBeingWatched, changedDashboardNames, changedGraphs)...)
-		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardssBeingWatched, changedDashboardNames, changedHierarchies)...)
-		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardssBeingWatched, changedDashboardNames, changedImages)...)
-		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardssBeingWatched, changedDashboardNames, changedInputs)...)
-		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardssBeingWatched, changedDashboardNames, changedTables)...)
-		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardssBeingWatched, changedDashboardNames, changedTexts)...)
+		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardsBeingWatched, changedDashboardNames, changedBenchmarks)...)
+		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardsBeingWatched, changedDashboardNames, changedCategories)...)
+		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardsBeingWatched, changedDashboardNames, changedContainers)...)
+		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardsBeingWatched, changedDashboardNames, changedControls)...)
+		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardsBeingWatched, changedDashboardNames, changedCards)...)
+		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardsBeingWatched, changedDashboardNames, changedCharts)...)
+		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardsBeingWatched, changedDashboardNames, changedEdges)...)
+		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardsBeingWatched, changedDashboardNames, changedFlows)...)
+		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardsBeingWatched, changedDashboardNames, changedGraphs)...)
+		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardsBeingWatched, changedDashboardNames, changedHierarchies)...)
+		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardsBeingWatched, changedDashboardNames, changedImages)...)
+		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardsBeingWatched, changedDashboardNames, changedInputs)...)
+		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardsBeingWatched, changedDashboardNames, changedNodes)...)
+		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardsBeingWatched, changedDashboardNames, changedTables)...)
+		changedDashboardNames = append(changedDashboardNames, getDashboardsInterestedInResourceChanges(dashboardsBeingWatched, changedDashboardNames, changedTexts)...)
 
 		for _, changedDashboard := range changedDashboards {
 			if helpers.StringSliceContains(changedDashboardNames, changedDashboard.Name) {
@@ -278,12 +283,6 @@ func (s *Server) HandleDashboardEvent(event dashboardevents.DashboardEvent) {
 			}
 		}
 
-	case *dashboardevents.DashboardError:
-		log.Println("[TRACE] dashboard error event", *e)
-
-	case *dashboardevents.DashboardComplete:
-		log.Println("[TRACE] dashboard complete event", *e)
-
 	case *dashboardevents.InputValuesCleared:
 		log.Println("[TRACE] input values cleared event", *e)
 
