@@ -11,7 +11,7 @@ import (
 	"sync"
 	"syscall"
 
-	"github.com/jackc/pgx/v4"
+	"github.com/jackc/pgx/v5"
 	psutils "github.com/shirou/gopsutil/process"
 	"github.com/spf13/viper"
 	"github.com/turbot/go-kit/helpers"
@@ -283,7 +283,7 @@ func resolvePassword() (string, error) {
 }
 
 func startPostgresProcess(ctx context.Context, port int, listen StartListenType, invoker constants.Invoker) (*exec.Cmd, error) {
-	if utils.IsContextCancelled(ctx) {
+	if error_helpers.IsContextCanceled(ctx) {
 		return nil, ctx.Err()
 	}
 
