@@ -19,7 +19,7 @@ func ShowVarsListTable(vars []*modconfig.Variable) {
 	headers := []string{"mod_name", "name", "description", "value", "value_default", "type"}
 	var rows = make([][]string, len(vars))
 	for i, v := range vars {
-		rows[i] = []string{v.ModName, v.ShortName, v.Description, fmt.Sprintf("%v", v.ValueGo), fmt.Sprintf("%v", v.DefaultGo), v.TypeString}
+		rows[i] = []string{v.ModName, v.ShortName, v.GetDescription(), fmt.Sprintf("%v", v.ValueGo), fmt.Sprintf("%v", v.DefaultGo), v.TypeString}
 	}
 	ShowWrappedTable(headers, rows, &ShowWrappedTableOptions{AutoMerge: false})
 }
