@@ -3,11 +3,12 @@ package initialisation
 import (
 	"context"
 	"fmt"
+	"github.com/turbot/steampipe/pkg/error_helpers"
 
-	"github.com/jackc/pgx/v4"
+	"github.com/jackc/pgx/v5"
 	"github.com/spf13/viper"
 	"github.com/turbot/go-kit/helpers"
-	"github.com/turbot/steampipe-plugin-sdk/v4/telemetry"
+	"github.com/turbot/steampipe-plugin-sdk/v5/telemetry"
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/db/db_client"
 	"github.com/turbot/steampipe/pkg/db/db_common"
@@ -16,7 +17,6 @@ import (
 	"github.com/turbot/steampipe/pkg/modinstaller"
 	"github.com/turbot/steampipe/pkg/statushooks"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
-	"github.com/turbot/steampipe/pkg/utils"
 	"github.com/turbot/steampipe/pkg/workspace"
 )
 
@@ -114,14 +114,7 @@ func (i *InitData) Init(ctx context.Context, invoker constants.Invoker) (res *In
 	sessionDataSource := workspace.NewSessionDataSource(i.Workspace, i.PreparedStatementSource)
 	// define db connection callback function
 	ensureSessionData := func(ctx context.Context, conn *pgx.Conn) error {
-		// if we are connecting to Steampipecloud, combine prepared statement sql when creating prepared statements
-		// to optimise performance
-		combineSql := cloudMetadata != nil
-		err, preparedStatementFailures := workspace.EnsureSessionData(ctx, sessionDataSource, conn, combineSql)
-
-		i.Workspace.HandlePreparedStatementFailures(preparedStatementFailures)
-
-		return err
+		return workspace.EnsureSessionData(ctx, sessionDataSource, conn)
 	}
 
 	// get a client
@@ -151,19 +144,16 @@ func (i *InitData) Init(ctx context.Context, invoker constants.Invoker) (res *In
 	if sessionResult.Error != nil {
 		i.Result.Error = fmt.Errorf("error acquiring database connection, %s", sessionResult.Error.Error())
 	} else {
-		sessionResult.Session.Close(utils.IsContextCancelled(ctx))
+		sessionResult.Session.Close(error_helpers.IsContextCanceled(ctx))
 	}
 	// add refresh connection warnings
 	i.Result.AddWarnings(refreshResult.Warnings...)
-	// add warnings from prepared statement creation
-	i.Result.AddPreparedStatementFailures(i.Workspace.GetPreparedStatementFailures())
 
 	return
 }
 
 // GetDbClient either creates a DB client using the configured connection string (if present) or creates a LocalDbClient
 func GetDbClient(ctx context.Context, invoker constants.Invoker, onConnectionCallback db_client.DbConnectionCallback) (client db_common.Client, err error) {
-
 	if connectionString := viper.GetString(constants.ArgConnectionString); connectionString != "" {
 		client, err = db_client.NewDbClient(ctx, connectionString, onConnectionCallback)
 	} else {
