@@ -6,8 +6,9 @@ import (
 	"sort"
 	"strings"
 
-	"github.com/turbot/steampipe-plugin-sdk/v4/grpc/proto"
-	"github.com/turbot/steampipe-plugin-sdk/v4/plugin"
+	"github.com/turbot/go-kit/helpers"
+	"github.com/turbot/steampipe-plugin-sdk/v5/grpc/proto"
+	"github.com/turbot/steampipe-plugin-sdk/v5/plugin"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 	"github.com/turbot/steampipe/pkg/utils"
 )
@@ -19,12 +20,13 @@ type ConnectionUpdates struct {
 	// the connections which will exist after the update
 	RequiredConnectionState ConnectionDataMap
 	// connection plugins required to perform the updates
-	ConnectionPlugins      map[string]*ConnectionPlugin
-	currentConnectionState ConnectionDataMap
+	ConnectionPlugins       map[string]*ConnectionPlugin
+	ConnectionStateModified bool
+	currentConnectionState  ConnectionDataMap
 }
 
 // NewConnectionUpdates returns updates to be made to the database to sync with connection config
-func NewConnectionUpdates(schemaNames []string) (*ConnectionUpdates, *RefreshConnectionResult) {
+func NewConnectionUpdates(schemaNames []string, forceUpdateConnectionNames ...string) (*ConnectionUpdates, *RefreshConnectionResult) {
 	utils.LogTime("NewConnectionUpdates start")
 	defer utils.LogTime("NewConnectionUpdates end")
 
@@ -47,12 +49,13 @@ func NewConnectionUpdates(schemaNames []string) (*ConnectionUpdates, *RefreshCon
 
 	// load the connection state file and filter out any connections which are not in the list of schemas
 	// this allows for the database being rebuilt,modified externally
-	currentConnectionState, err := GetConnectionState(schemaNames)
+	currentConnectionState, stateModified, err := GetConnectionState(schemaNames)
 	if err != nil {
 		res.Error = err
 		return nil, res
 	}
 	updates.currentConnectionState = currentConnectionState
+	updates.ConnectionStateModified = stateModified
 
 	// for any connections with dynamic schema, we need to reload their schema
 	// instantiate connection plugins for all connections with dynamic schema - this will retrieve their current schema
@@ -65,9 +68,11 @@ func NewConnectionUpdates(schemaNames []string) (*ConnectionUpdates, *RefreshCon
 	// connections to create/update
 	for name, requiredConnectionData := range requiredConnectionState {
 		// check whether this connection exists in the state
-		currentConnectionData, ok := currentConnectionState[name]
+		currentConnectionData, schemaExistsInState := currentConnectionState[name]
 		// if it does not exist, or is not equal, add to updates
-		if !ok || !currentConnectionData.Equals(requiredConnectionData) {
+		if helpers.StringSliceContains(forceUpdateConnectionNames, name) ||
+			!schemaExistsInState ||
+			!currentConnectionData.Equals(requiredConnectionData) {
 			log.Printf("[TRACE] connection %s is out of date or missing\n", name)
 			updates.Update[name] = requiredConnectionData
 		}
@@ -262,5 +267,5 @@ func pluginSchemaHash(s *proto.Schema) string {
 		}
 	}
 	str := sb.String()
-	return utils.GetMD5Hash(str)
+	return helpers.GetMD5Hash(str)
 }
