@@ -12,15 +12,15 @@ import (
 	"github.com/turbot/steampipe/pkg/steampipeconfig/inputvars"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/parse"
-	"github.com/turbot/steampipe/pkg/utils"
+	"github.com/turbot/steampipe/pkg/type_conversion"
 )
 
 func LoadVariableDefinitions(variablePath string, parseCtx *parse.ModParseContext) (*modconfig.ModVariableMap, error) {
 	// only load mod and variables blocks
 	parseCtx.BlockTypes = []string{modconfig.BlockTypeVariable}
-	mod, err := LoadMod(variablePath, parseCtx)
-	if err != nil {
-		return nil, err
+	mod, errAndWarnings := LoadMod(variablePath, parseCtx)
+	if errAndWarnings.GetError() != nil {
+		return nil, errAndWarnings.GetError()
 	}
 
 	variableMap := modconfig.NewModVariableMap(mod, parseCtx.LoadedDependencyMods)
@@ -50,7 +50,7 @@ func GetVariableValues(ctx context.Context, parseCtx *parse.ModParseContext, var
 			inputValue.SourceRange)
 
 		// set variable value string in our workspace map
-		variableMap.VariableValues[name], err = utils.CtyToString(inputValue.Value)
+		variableMap.VariableValues[name], err = type_conversion.CtyToString(inputValue.Value)
 		if err != nil {
 			return nil, err
 		}
