@@ -2,13 +2,13 @@ package modconfig
 
 import (
 	"fmt"
+	typehelpers "github.com/turbot/go-kit/types"
+	"github.com/zclconf/go-cty/cty"
 	"strings"
 
 	"github.com/hashicorp/hcl/v2"
 	"github.com/stevenle/topsort"
-	typehelpers "github.com/turbot/go-kit/types"
 	"github.com/turbot/steampipe/pkg/utils"
-	"github.com/zclconf/go-cty/cty"
 )
 
 const rootRuntimeDependencyNode = "rootRuntimeDependencyNode"
@@ -16,48 +16,39 @@ const runtimeDependencyDashboardScope = "self"
 
 // Dashboard is a struct representing the Dashboard  resource
 type Dashboard struct {
-	ResourceWithMetadataBase
+	ResourceWithMetadataImpl
+	ModTreeItemImpl
+	WithProviderImpl
 
 	// required to allow partial decoding
-	Remain hcl.Body `hcl:",remain"`
+	Remain hcl.Body `hcl:",remain" json:"-"`
 
-	ShortName       string
-	FullName        string            `cty:"name"`
-	UnqualifiedName string            `cty:"unqualified_name"`
-	Title           *string           `cty:"title" hcl:"title" column:"title,text"`
-	Width           *int              `cty:"width" hcl:"width"  column:"width,text"`
-	Display         *string           `cty:"display" hcl:"display" column:"display,text"`
-	Inputs          []*DashboardInput `cty:"inputs" column:"inputs,jsonb"`
-	Description     *string           `cty:"description" hcl:"description" column:"description,text"`
-	Documentation   *string           `cty:"documentation" hcl:"documentation" column:"documentation,text"`
-	Tags            map[string]string `cty:"tags" hcl:"tags,optional"  column:"tags,jsonb"`
-	UrlPath         string            `cty:"url_path"  column:"url_path,jsonb"`
-
-	Base *Dashboard `hcl:"base"`
-
-	References []*ResourceReference
-	Mod        *Mod `cty:"mod"`
-	DeclRange  hcl.Range
-
-	Paths []NodePath `column:"path,jsonb"`
+	Width   *int              `cty:"width" hcl:"width"  column:"width,text"`
+	Display *string           `cty:"display" hcl:"display" column:"display,text"`
+	Inputs  []*DashboardInput `cty:"inputs" column:"inputs,jsonb"`
+	UrlPath string            `cty:"url_path"  column:"url_path,jsonb"`
+	Base    *Dashboard        `hcl:"base"`
 	// store children in a way which can be serialised via cty
 	ChildNames []string `cty:"children" column:"children,jsonb"`
-
-	selfInputsMap map[string]*DashboardInput
-	// the actual children
-	children []ModTreeItem
-	// TODO [reports] can a dashboard ever have multiple parents??
-	parents                []ModTreeItem
+	// map of all inputs in our resource tree
+	selfInputsMap          map[string]*DashboardInput
 	runtimeDependencyGraph *topsort.Graph
 }
 
 func NewDashboard(block *hcl.Block, mod *Mod, shortName string) HclResource {
+	fullName := fmt.Sprintf("%s.%s.%s", mod.ShortName, block.Type, shortName)
+
 	c := &Dashboard{
-		ShortName:       shortName,
-		FullName:        fmt.Sprintf("%s.%s.%s", mod.ShortName, block.Type, shortName),
-		UnqualifiedName: fmt.Sprintf("%s.%s", block.Type, shortName),
-		Mod:             mod,
-		DeclRange:       block.DefRange,
+		ModTreeItemImpl: ModTreeItemImpl{
+			HclResourceImpl: HclResourceImpl{
+				ShortName:       shortName,
+				FullName:        fullName,
+				UnqualifiedName: fmt.Sprintf("%s.%s", block.Type, shortName),
+				DeclRange:       block.DefRange,
+				blockType:       block.Type,
+			},
+			Mod: mod,
+		},
 	}
 	c.SetAnonymous(block)
 	c.setUrlPath()
@@ -75,17 +66,22 @@ func NewQueryDashboard(q ModTreeItem) (*Dashboard, error) {
 	dashboardName := BuildFullResourceName(q.GetMod().ShortName, BlockTypeDashboard, parsedName.Name)
 
 	var dashboard = &Dashboard{
-		ResourceWithMetadataBase: ResourceWithMetadataBase{
+		ResourceWithMetadataImpl: ResourceWithMetadataImpl{
 			metadata: &ResourceMetadata{},
 		},
-		ShortName:       parsedName.Name,
-		FullName:        dashboardName,
-		UnqualifiedName: fmt.Sprintf("%s.%s", BlockTypeDashboard, parsedName),
-		Title:           utils.ToStringPointer(q.GetTitle()),
-		Description:     utils.ToStringPointer(q.GetDescription()),
-		Documentation:   utils.ToStringPointer(q.GetDocumentation()),
-		Tags:            q.GetTags(),
-		Mod:             q.GetMod(),
+		ModTreeItemImpl: ModTreeItemImpl{
+			HclResourceImpl: HclResourceImpl{
+				ShortName:       parsedName.Name,
+				FullName:        dashboardName,
+				UnqualifiedName: fmt.Sprintf("%s.%s", BlockTypeDashboard, parsedName),
+				Title:           utils.ToStringPointer(q.GetTitle()),
+				Description:     utils.ToStringPointer(q.GetDescription()),
+				Documentation:   utils.ToStringPointer(q.GetDocumentation()),
+				Tags:            q.GetTags(),
+				blockType:       BlockTypeDashboard,
+			},
+			Mod: q.GetMod(),
+		},
 	}
 
 	dashboard.setUrlPath()
@@ -108,19 +104,9 @@ func (d *Dashboard) Equals(other *Dashboard) bool {
 	return !diff.HasChanges()
 }
 
-// CtyValue implements HclResource
-func (d *Dashboard) CtyValue() (cty.Value, error) {
-	return getCtyValue(d)
-}
-
-// Name implements HclResource, ModTreeItem
-func (d *Dashboard) Name() string {
-	return d.FullName
-}
-
 // OnDecoded implements HclResource
 func (d *Dashboard) OnDecoded(block *hcl.Block, resourceMapProvider ResourceMapsProvider) hcl.Diagnostics {
-	d.setBaseProperties(resourceMapProvider)
+	d.setBaseProperties()
 
 	d.ChildNames = make([]string, len(d.children))
 	for i, child := range d.children {
@@ -130,88 +116,24 @@ func (d *Dashboard) OnDecoded(block *hcl.Block, resourceMapProvider ResourceMaps
 	return nil
 }
 
-// AddReference implements ResourceWithMetadata
-func (d *Dashboard) AddReference(ref *ResourceReference) {
-	d.References = append(d.References, ref)
+// GetWidth implements DashboardLeafNode
+func (d *Dashboard) GetWidth() int {
+	if d.Width == nil {
+		return 0
+	}
+	return *d.Width
 }
 
-// GetReferences implements ResourceWithMetadata
-func (d *Dashboard) GetReferences() []*ResourceReference {
-	return d.References
+// GetDisplay implements DashboardLeafNode
+func (d *Dashboard) GetDisplay() string {
+	return typehelpers.SafeString(d.Display)
 }
 
-// GetMod implements ModTreeItem
-func (d *Dashboard) GetMod() *Mod {
-	return d.Mod
-}
-
-// GetDeclRange implements HclResource
-func (d *Dashboard) GetDeclRange() *hcl.Range {
-	return &d.DeclRange
-}
-
-// BlockType implements HclResource
-func (*Dashboard) BlockType() string {
-	return BlockTypeDashboard
-}
-
-// AddParent implements ModTreeItem
-func (d *Dashboard) AddParent(parent ModTreeItem) error {
-	d.parents = append(d.parents, parent)
-	return nil
-}
-
-// GetParents implements ModTreeItem
-func (d *Dashboard) GetParents() []ModTreeItem {
-	return d.parents
-}
-
-// GetChildren implements ModTreeItem
-func (d *Dashboard) GetChildren() []ModTreeItem {
-	return d.children
-}
-
-// GetTitle implements HclResource
-func (d *Dashboard) GetTitle() string {
-	return typehelpers.SafeString(d.Title)
-}
-
-// GetDescription implements ModTreeItem
-func (d *Dashboard) GetDescription() string {
+// GetType implements DashboardLeafNode
+func (d *Dashboard) GetType() string {
 	return ""
 }
 
-// GetTags implements HclResource
-func (d *Dashboard) GetTags() map[string]string {
-	if d.Tags != nil {
-		return d.Tags
-	}
-	return map[string]string{}
-}
-
-// GetPaths implements ModTreeItem
-func (d *Dashboard) GetPaths() []NodePath {
-	// lazy load
-	if len(d.Paths) == 0 {
-		d.SetPaths()
-	}
-	return d.Paths
-}
-
-// SetPaths implements ModTreeItem
-func (d *Dashboard) SetPaths() {
-	for _, parent := range d.parents {
-		for _, parentPath := range parent.GetPaths() {
-			d.Paths = append(d.Paths, append(parentPath, d.Name()))
-		}
-	}
-}
-
-// GetDocumentation implement ModTreeItem
-func (d *Dashboard) GetDocumentation() string {
-	return typehelpers.SafeString(d.Documentation)
-}
-
 func (d *Dashboard) Diff(other *Dashboard) *DashboardTreeItemDiffs {
 	res := &DashboardTreeItemDiffs{
 		Item: d,
@@ -258,11 +180,13 @@ func (d *Dashboard) SetChildren(children []ModTreeItem) {
 
 func (d *Dashboard) AddChild(child ModTreeItem) {
 	d.children = append(d.children, child)
-}
 
-// GetUnqualifiedName implements DashboardLeafNode, ModTreeItem
-func (d *Dashboard) GetUnqualifiedName() string {
-	return d.UnqualifiedName
+	switch c := child.(type) {
+	case *DashboardInput:
+		d.Inputs = append(d.Inputs, c)
+	case *DashboardWith:
+		d.AddWith(c)
+	}
 }
 
 func (d *Dashboard) WalkResources(resourceFunc func(resource HclResource) (bool, error)) error {
@@ -275,8 +199,8 @@ func (d *Dashboard) WalkResources(resourceFunc func(resource HclResource) (bool,
 			break
 		}
 
-		if childContainer, ok := child.(*DashboardContainer); ok {
-			if err := childContainer.WalkResources(resourceFunc); err != nil {
+		if container, ok := child.(*DashboardContainer); ok {
+			if err := container.WalkResources(resourceFunc); err != nil {
 				return err
 			}
 		}
@@ -284,44 +208,27 @@ func (d *Dashboard) WalkResources(resourceFunc func(resource HclResource) (bool,
 	return nil
 }
 
-func (d *Dashboard) BuildRuntimeDependencyTree(workspace ResourceMapsProvider) error {
+func (d *Dashboard) ValidateRuntimeDependencies(workspace ResourceMapsProvider) error {
 	d.runtimeDependencyGraph = topsort.NewGraph()
 	// add root node - this will depend on all other nodes
 	d.runtimeDependencyGraph.AddNode(rootRuntimeDependencyNode)
 
-	// define a walk function which determins whether the resource has runtime dependencies and if so,
+	// define a walk function which determines whether the resource has runtime dependencies and if so,
 	// add to the graph
 	resourceFunc := func(resource HclResource) (bool, error) {
-		// currently only QueryProvider resources support runtime dependencies
-		queryProvider, ok := resource.(QueryProvider)
+		wp, ok := resource.(WithProvider)
 		if !ok {
 			// continue walking
 			return true, nil
 		}
 
-		runtimeDependencies := queryProvider.GetRuntimeDependencies()
-		if len(runtimeDependencies) == 0 {
-			// continue walking
-			return true, nil
-		}
-		name := resource.Name()
-		if !d.runtimeDependencyGraph.ContainsNode(name) {
-			d.runtimeDependencyGraph.AddNode(name)
+		if err := d.validateRuntimeDependenciesForResource(resource, workspace); err != nil {
+			return false, err
 		}
 
-		for _, dependency := range runtimeDependencies {
-			// try to resolve the dependency source resource
-			if err := dependency.ResolveSource(d, workspace); err != nil {
-				return false, err
-			}
-			if err := d.runtimeDependencyGraph.AddEdge(rootRuntimeDependencyNode, name); err != nil {
-				return false, err
-			}
-			depString := dependency.String()
-			if !d.runtimeDependencyGraph.ContainsNode(depString) {
-				d.runtimeDependencyGraph.AddNode(depString)
-			}
-			if err := d.runtimeDependencyGraph.AddEdge(name, dependency.String()); err != nil {
+		// if the query provider has any 'with' blocks, add these dependencies as well
+		for _, with := range wp.GetWiths() {
+			if err := d.validateRuntimeDependenciesForResource(with, workspace); err != nil {
 				return false, err
 			}
 		}
@@ -340,15 +247,49 @@ func (d *Dashboard) BuildRuntimeDependencyTree(workspace ResourceMapsProvider) e
 	return nil
 }
 
+func (d *Dashboard) validateRuntimeDependenciesForResource(resource HclResource, workspace ResourceMapsProvider) error {
+	// TODO  [node_reuse] re-add parse time validation https://github.com/turbot/steampipe/issues/2925
+	return nil
+	//rdp := resource.(RuntimeDependencyProvider)
+	//// WHAT ABOUT CHILDREN
+	//if len(runtimeDependencies) == 0 {
+	//	return nil
+	//}
+	//name := resource.Name()
+	//if !d.runtimeDependencyGraph.ContainsNode(name) {
+	//	d.runtimeDependencyGraph.AddNode(name)
+	//}
+	//
+	//for _, dependency := range runtimeDependencies {
+	//	// try to resolve the dependency source resource
+	//	if err := dependency.ValidateSource(d, workspace); err != nil {
+	//		return err
+	//	}
+	//	if err := d.runtimeDependencyGraph.AddEdge(rootRuntimeDependencyNode, name); err != nil {
+	//		return err
+	//	}
+	//	depString := dependency.String()
+	//	if !d.runtimeDependencyGraph.ContainsNode(depString) {
+	//		d.runtimeDependencyGraph.AddNode(depString)
+	//	}
+	//	if err := d.runtimeDependencyGraph.AddEdge(name, dependency.String()); err != nil {
+	//		return err
+	//	}
+	//}
+	//return nil
+}
+
 func (d *Dashboard) GetInput(name string) (*DashboardInput, bool) {
 	input, found := d.selfInputsMap[name]
 	return input, found
 }
 
-func (d *Dashboard) SetInputs(inputs []*DashboardInput) hcl.Diagnostics {
-	d.Inputs = inputs
+func (d *Dashboard) GetInputs() map[string]*DashboardInput {
+	return d.selfInputsMap
+}
 
-	// add all our direct child inputs to a mp
+func (d *Dashboard) InitInputs() hcl.Diagnostics {
+	// add all our direct child inputs to a map
 	// (we must do this before adding child container inputs to detect dupes)
 	duplicates := d.setInputMap()
 
@@ -387,7 +328,7 @@ func (d *Dashboard) SetInputs(inputs []*DashboardInput) hcl.Diagnostics {
 
 	var diags hcl.Diagnostics
 	//  ensure they inputs not have cyclical dependencies
-	if err := d.validateInputDependencies(inputs); err != nil {
+	if err := d.validateInputDependencies(d.Inputs); err != nil {
 		return hcl.Diagnostics{&hcl.Diagnostic{
 			Severity: hcl.DiagError,
 			Summary:  fmt.Sprintf("Failed to resolve input dependency order for dashboard '%s'", d.Name()),
@@ -396,7 +337,7 @@ func (d *Dashboard) SetInputs(inputs []*DashboardInput) hcl.Diagnostics {
 		}}
 	}
 	// now 'claim' all inputs and add to mod
-	for _, input := range inputs {
+	for _, input := range d.Inputs {
 		input.SetDashboard(d)
 		moreDiags := d.Mod.AddResource(input)
 		diags = append(diags, moreDiags...)
@@ -419,19 +360,19 @@ func (d *Dashboard) setInputMap() []string {
 	return duplicates
 }
 
-func (d *Dashboard) setBaseProperties(resourceMapProvider ResourceMapsProvider) {
-	// not all base properties are stored in the evalContext
-	// (e.g. resource metadata and runtime dependencies are not stores)
-	//  so resolve base from the resource map provider (which is the RunContext)
-	if base, resolved := resolveBase(d.Base, resourceMapProvider); !resolved {
-		return
-	} else {
-		d.Base = base.(*Dashboard)
-	}
+// CtyValue implements CtyValueProvider
+func (d *Dashboard) CtyValue() (cty.Value, error) {
+	return GetCtyValue(d)
+}
 
-	if d.Title == nil {
-		d.Title = d.Base.Title
+func (d *Dashboard) setBaseProperties() {
+	if d.Base == nil {
+		return
 	}
+	// copy base into the HclResourceImpl 'base' property so it is accessible to all nested structs
+	d.base = d.Base
+	// call into parent nested struct setBaseProperties
+	d.ModTreeItemImpl.setBaseProperties()
 
 	if d.Width == nil {
 		d.Width = d.Base.Width
@@ -443,16 +384,6 @@ func (d *Dashboard) setBaseProperties(resourceMapProvider ResourceMapsProvider)
 	}
 
 	d.addBaseInputs(d.Base.Inputs)
-
-	d.Tags = utils.MergeMaps(d.Tags, d.Base.Tags)
-
-	if d.Description == nil {
-		d.Description = d.Base.Description
-	}
-
-	if d.Documentation == nil {
-		d.Documentation = d.Base.Documentation
-	}
 }
 
 func (d *Dashboard) addBaseInputs(baseInputs []*DashboardInput) {
@@ -480,7 +411,7 @@ func (d *Dashboard) addBaseInputs(baseInputs []*DashboardInput) {
 	d.setInputMap()
 }
 
-// ensure that depdnecneis between inputs are resolveable
+// ensure that dependencies between inputs are resolveable
 func (d *Dashboard) validateInputDependencies(inputs []*DashboardInput) error {
 	dependencyGraph := topsort.NewGraph()
 	rootDependencyNode := "dashboard"
