@@ -6,29 +6,31 @@ import (
 )
 
 // MappableResource must be implemented by resources which can be created
-// directly from a content file (e.g. sql, markdown)
+// directly from a content file (e.g. sql)
 type MappableResource interface {
+	HclResource
+	ResourceWithMetadata
 	// InitialiseFromFile creates a mappable resource from a file path
 	// It returns the resource, and the raw file data
 	InitialiseFromFile(modPath, filePath string) (MappableResource, []byte, error)
-	Name() string
-	GetUnqualifiedName() string
-	GetMetadata() *ResourceMetadata
-	SetMetadata(*ResourceMetadata)
-	GetDeclRange() *hcl.Range
 }
 
 // HclResource must be implemented by resources defined in HCL
 type HclResource interface {
+	// TODO  [node_reuse] rename to GetName/GetFullName
 	Name() string
 	GetTitle() string
 	GetUnqualifiedName() string
-	CtyValue() (cty.Value, error)
 	OnDecoded(*hcl.Block, ResourceMapsProvider) hcl.Diagnostics
 	GetDeclRange() *hcl.Range
 	BlockType() string
 	GetDescription() string
+	GetDocumentation() string
 	GetTags() map[string]string
+	SetTopLevel(bool)
+	IsTopLevel() bool
+	GetBase() HclResource
+	GetHclResourceImpl() *HclResourceImpl
 }
 
 // ModTreeItem must be implemented by elements of the mod resource hierarchy
@@ -38,11 +40,46 @@ type ModTreeItem interface {
 	AddParent(ModTreeItem) error
 	GetParents() []ModTreeItem
 	GetChildren() []ModTreeItem
-	GetDocumentation() string
 	// GetPaths returns an array resource paths
 	GetPaths() []NodePath
 	SetPaths()
 	GetMod() *Mod
+	GetModTreeItemImpl() *ModTreeItemImpl
+}
+
+// RuntimeDependencyProvider is implemented by all QueryProviders and Dashboard
+type RuntimeDependencyProvider interface {
+	ModTreeItem
+	AddRuntimeDependencies([]*RuntimeDependency)
+	GetRuntimeDependencies() map[string]*RuntimeDependency
+}
+
+type WithProvider interface {
+	AddWith(with *DashboardWith) hcl.Diagnostics
+	GetWiths() []*DashboardWith
+	GetWith(string) (*DashboardWith, bool)
+}
+
+// QueryProvider must be implemented by resources which supports prepared statements, i.e. Control and Query
+type QueryProvider interface {
+	RuntimeDependencyProvider
+	GetArgs() *QueryArgs
+	GetParams() []*ParamDef
+	GetSQL() *string
+	GetQuery() *Query
+	SetArgs(*QueryArgs)
+	SetParams([]*ParamDef)
+	GetResolvedQuery(*QueryArgs) (*ResolvedQuery, error)
+	RequiresExecution(QueryProvider) bool
+	ValidateQuery() hcl.Diagnostics
+	MergeParentArgs(QueryProvider, QueryProvider) hcl.Diagnostics
+	GetQueryProviderImpl() *QueryProviderImpl
+	ParamsInheritedFromBase() bool
+	ArgsInheritedFromBase() bool
+}
+
+type CtyValueProvider interface {
+	CtyValue() (cty.Value, error)
 }
 
 // ResourceWithMetadata must be implemented by resources which supports reflection metadata
@@ -56,52 +93,29 @@ type ResourceWithMetadata interface {
 	GetReferences() []*ResourceReference
 }
 
-// QueryProvider must be implemented by resources which supports prepared statements, i.e. Control and Query
-type QueryProvider interface {
-	HclResource
-	GetArgs() *QueryArgs
-	GetParams() []*ParamDef
-	GetSQL() *string
-	GetQuery() *Query
-	SetArgs(*QueryArgs)
-	SetParams([]*ParamDef)
-	GetMod() *Mod
-	GetDescription() string
-	GetPreparedStatementName() string
-	GetPreparedStatementExecuteSQL(*QueryArgs) (*ResolvedQuery, error)
-	// implemented by QueryProviderBase
-	AddRuntimeDependencies([]*RuntimeDependency)
-	GetRuntimeDependencies() map[string]*RuntimeDependency
-	RequiresExecution(QueryProvider) bool
-	VerifyQuery(QueryProvider) error
-	MergeParentArgs(QueryProvider, QueryProvider) (diags hcl.Diagnostics)
-}
-
 // DashboardLeafNode must be implemented by resources may be a leaf node in the dashboard execution tree
 type DashboardLeafNode interface {
-	HclResource
-	GetTitle() string
+	ModTreeItem
+	ResourceWithMetadata
 	GetDisplay() string
-	GetDescription() string
-	GetDocumentation() string
 	GetType() string
-	GetTags() map[string]string
 	GetWidth() int
-	GetPaths() []NodePath
-	GetMetadata() *ResourceMetadata
-	GetChildren() []ModTreeItem
 }
+
 type ResourceMapsProvider interface {
 	GetResourceMaps() *ResourceMaps
 }
 
-// EdgeAndNodeProvider must be implemented by any dashboard leaf node which supports edges and nodes
+// NodeAndEdgeProvider must be implemented by any dashboard leaf node which supports edges and nodes
 // (DashboardGraph, DashboardFlow, DashboardHierarchy)
-type EdgeAndNodeProvider interface {
+// TODO [node_reuse] add NodeAndEdgeProviderImpl https://github.com/turbot/steampipe/issues/2918
+type NodeAndEdgeProvider interface {
 	QueryProvider
+	WithProvider
 	GetEdges() DashboardEdgeList
 	SetEdges(DashboardEdgeList)
 	GetNodes() DashboardNodeList
 	SetNodes(DashboardNodeList)
 	AddCategory(category *DashboardCategory) hcl.Diagnostics
+	AddChild(child HclResource) hcl.Diagnostics
 }
