@@ -57,30 +57,21 @@ type Workspace struct {
 	loadPseudoResources        bool
 	// channel used to send dashboard events to the handleDashbooardEvent goroutine
 	dashboardEventChan chan dashboardevents.DashboardEvent
-	// count of workspace changed events - used to ignore first event
-	changeEventCount int
-	// avoid concurrent map access when multiple db connections may try to access preparedStatementFailures
-	preparedStatementFailureLock sync.Mutex
-	preparedStatementFailures    map[string]*steampipeconfig.PreparedStatementFailure
 }
 
 // Load creates a Workspace and loads the workspace mod
-func Load(ctx context.Context, workspacePath string) (*Workspace, error) {
+func Load(ctx context.Context, workspacePath string) (*Workspace, *modconfig.ErrorAndWarnings) {
 	utils.LogTime("workspace.Load start")
 	defer utils.LogTime("workspace.Load end")
 
 	workspace, err := createShellWorkspace(workspacePath)
 	if err != nil {
-		return nil, err
+		return nil, modconfig.NewErrorsAndWarning(err)
 	}
 
 	// load the workspace mod
-	if err := workspace.loadWorkspaceMod(ctx); err != nil {
-		return nil, err
-	}
-
-	// return context error so calling code can handle cancellations
-	return workspace, nil
+	errAndWarnings := workspace.loadWorkspaceMod(ctx)
+	return workspace, errAndWarnings
 }
 
 // LoadVariables creates a Workspace and uses it to load all variables, ignoring any value resolution errors
@@ -152,6 +143,7 @@ func (w *Workspace) SetupWatcher(ctx context.Context, client db_common.Client, e
 		Include:     filehelpers.InclusionsFromExtensions(steampipeconfig.GetModFileExtensions()),
 		Exclude:     w.exclusions,
 		ListFlag:    w.listFlag,
+		EventMask:   fsnotify.Create | fsnotify.Remove | fsnotify.Rename | fsnotify.Write,
 		// we should look into passing the callback function into the underlying watcher
 		// we need to analyze the kind of errors that come out from the watcher and
 		// decide how to handle them
@@ -201,43 +193,6 @@ func (w *Workspace) ModfileExists() bool {
 	return len(w.modFilePath) > 0
 }
 
-func (w *Workspace) HandlePreparedStatementFailures(failures *db_common.PrepareStatementFailures) {
-	if failures == nil {
-		return
-	}
-
-	// avoid concurrent map access when multiple db connections may try to access preparedStatementFailures
-	w.preparedStatementFailureLock.Lock()
-	defer w.preparedStatementFailureLock.Unlock()
-
-	// replace the map of failures with the current map
-	w.preparedStatementFailures = make(map[string]*steampipeconfig.PreparedStatementFailure)
-	for queryName, err := range failures.Failures {
-		if query, ok := w.GetQueryProvider(queryName); ok {
-			w.preparedStatementFailures[queryName] = &steampipeconfig.PreparedStatementFailure{
-				Query: query,
-				Error: err,
-			}
-		}
-	}
-	if failures.Error != nil {
-		w.preparedStatementFailures["preparedStatementGlobalError"] = &steampipeconfig.PreparedStatementFailure{
-			Error: failures.Error,
-		}
-
-	}
-}
-
-// GetPreparedStatementCreationFailure looks for a prepared statement error for the given query and if found,
-// returns the query and the prepared statement creation error (if any)
-func (w *Workspace) GetPreparedStatementCreationFailure(queryName string) *steampipeconfig.PreparedStatementFailure {
-	return w.preparedStatementFailures[queryName]
-}
-
-func (w *Workspace) GetPreparedStatementFailures() map[string]*steampipeconfig.PreparedStatementFailure {
-	return w.preparedStatementFailures
-}
-
 // check  whether the workspace contains a modfile
 // this will determine whether we load files recursively, and create pseudo resources for sql files
 func (w *Workspace) setModfileExists() {
@@ -285,13 +240,13 @@ func (w *Workspace) findModFilePath(folder string) (string, error) {
 	return modFilePath, nil
 }
 
-func (w *Workspace) loadWorkspaceMod(ctx context.Context) error {
+func (w *Workspace) loadWorkspaceMod(ctx context.Context) *modconfig.ErrorAndWarnings {
 	// resolve values of all input variables
 	// we WILL validate missing variables when loading
 	validateMissing := true
 	inputVariables, err := w.getInputVariables(ctx, validateMissing)
 	if err != nil {
-		return err
+		return modconfig.NewErrorsAndWarning(err)
 	}
 	// populate the parsed variable values
 	w.VariableValues = inputVariables.VariableValues
@@ -299,7 +254,7 @@ func (w *Workspace) loadWorkspaceMod(ctx context.Context) error {
 	// build run context which we use to load the workspace
 	parseCtx, err := w.getParseContext()
 	if err != nil {
-		return err
+		return modconfig.NewErrorsAndWarning(err)
 	}
 	// add variables to runContext
 	parseCtx.AddInputVariables(inputVariables)
@@ -307,9 +262,9 @@ func (w *Workspace) loadWorkspaceMod(ctx context.Context) error {
 	parseCtx.BlockTypeExclusions = []string{modconfig.BlockTypeVariable}
 
 	// load the workspace mod
-	m, err := steampipeconfig.LoadMod(w.Path, parseCtx)
-	if err != nil {
-		return err
+	m, errorAndWarning := steampipeconfig.LoadMod(w.Path, parseCtx)
+	if errorAndWarning.Error != nil {
+		return errorAndWarning
 	}
 
 	// now set workspace properties
@@ -322,7 +277,9 @@ func (w *Workspace) loadWorkspaceMod(ctx context.Context) error {
 	w.Mods[w.Mod.Name()] = w.Mod
 
 	// verify all runtime dependencies can be resolved
-	return w.verifyResourceRuntimeDependencies()
+	errorAndWarning.Error = w.verifyResourceRuntimeDependencies()
+
+	return errorAndWarning
 }
 
 func (w *Workspace) getInputVariables(ctx context.Context, validateMissing bool) (*modconfig.ModVariableMap, error) {
@@ -389,8 +346,10 @@ func (w *Workspace) loadWorkspaceLock() (*versionmap.WorkspaceLock, error) {
 func (w *Workspace) loadExclusions() error {
 	// default to ignoring hidden files and folders
 	w.exclusions = []string{
-		fmt.Sprintf("%s/**/.*", w.Path),
+		// ignore any hidden folder
 		fmt.Sprintf("%s/.*", w.Path),
+		// and sub files/folders of hidden folders
+		fmt.Sprintf("%s/.*/**", w.Path),
 	}
 
 	ignorePath := filepath.Join(w.Path, filepaths.WorkspaceIgnoreFile)
@@ -438,7 +397,7 @@ func (w *Workspace) loadWorkspaceResourceName() (*modconfig.WorkspaceResources,
 
 func (w *Workspace) verifyResourceRuntimeDependencies() error {
 	for _, d := range w.Mod.ResourceMaps.Dashboards {
-		if err := d.BuildRuntimeDependencyTree(w); err != nil {
+		if err := d.ValidateRuntimeDependencies(w); err != nil {
 			return err
 		}
 	}
