@@ -4,7 +4,10 @@ import (
 	"context"
 	"fmt"
 	"log"
+	"reflect"
 	"strings"
+	"sync/atomic"
+	"time"
 
 	"github.com/fsnotify/fsnotify"
 	"github.com/turbot/steampipe/pkg/dashboard/dashboardevents"
@@ -13,10 +16,26 @@ import (
 	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 )
 
-func (w *Workspace) PublishDashboardEvent(e dashboardevents.DashboardEvent) {
+var EventCount int64 = 0
+
+func (w *Workspace) PublishDashboardEvent(ctx context.Context, e dashboardevents.DashboardEvent) {
 	if w.dashboardEventChan != nil {
-		// send an event onto the event bus
-		w.dashboardEventChan <- e
+		// NOTE: channel send stalls have been observed when the channel buffer was too small
+		// - timeout send after 1s and support cancellation while waiting for event send
+		var doneChan = make(chan struct{})
+		go func() {
+			// send an event onto the event bus
+			w.dashboardEventChan <- e
+			atomic.AddInt64(&EventCount, 1)
+			close(doneChan)
+		}()
+		select {
+		case <-doneChan:
+		case <-time.After(1 * time.Second):
+			log.Printf("[TRACE] timeout sending dashboard event %s, buffered events: %d", reflect.TypeOf(e).String(), EventCount)
+		case <-ctx.Done():
+			log.Printf("[TRACE] context cancelled sending dashboard event")
+		}
 	}
 }
 
@@ -25,7 +44,9 @@ func (w *Workspace) PublishDashboardEvent(e dashboardevents.DashboardEvent) {
 func (w *Workspace) RegisterDashboardEventHandler(handler dashboardevents.DashboardEventHandler) {
 	// if no event channel has been created we need to start the event handler goroutine
 	if w.dashboardEventChan == nil {
-		w.dashboardEventChan = make(chan dashboardevents.DashboardEvent, 20)
+		// create a fairly large channel buffer - event send stalls have been observed when this buffering is too low
+		// (not fully understood yet - this is a sticking plaster)
+		w.dashboardEventChan = make(chan dashboardevents.DashboardEvent, 200)
 		go w.handleDashboardEvent()
 	}
 	// now add the handler to our list
@@ -42,7 +63,9 @@ func (w *Workspace) UnregisterDashboardEventHandlers() {
 func (w *Workspace) handleDashboardEvent() {
 	for {
 		e := <-w.dashboardEventChan
+		atomic.AddInt64(&EventCount, -1)
 		if e == nil {
+			log.Printf("[TRACE] handleDashboardEvent nil event received - exiting")
 			w.dashboardEventChan = nil
 			return
 		}
@@ -53,18 +76,15 @@ func (w *Workspace) handleDashboardEvent() {
 	}
 }
 
-func (w *Workspace) handleFileWatcherEvent(ctx context.Context, client db_common.Client, _ []fsnotify.Event) {
-	// ignore the first event - this is raised as soon as we start the watcher
-	w.changeEventCount++
-	if w.changeEventCount == 1 {
-		log.Printf("[TRACE] Workspace handleFileWatcherEvent ignoring first event")
-		return
-	}
+func (w *Workspace) handleFileWatcherEvent(ctx context.Context, client db_common.Client, ev []fsnotify.Event) {
+	log.Printf("[TRACE] handleFileWatcherEvent")
+	prevResourceMaps, resourceMaps, errAndWarnings := w.reloadResourceMaps(ctx)
 
-	prevResourceMaps, resourceMaps, err := w.reloadResourceMaps(ctx)
-	if err != nil {
+	if errAndWarnings.GetError() != nil {
+		log.Printf("[TRACE] handleFileWatcherEvent reloadResourceMaps returned error - call PublishDashboardEvent")
 		// publish error event
-		w.PublishDashboardEvent(&dashboardevents.WorkspaceError{Error: err})
+		w.PublishDashboardEvent(ctx, &dashboardevents.WorkspaceError{Error: errAndWarnings.GetError()})
+		log.Printf("[TRACE] back from PublishDashboardEvent")
 		return
 	}
 	// if resources have changed, update introspection tables and prepared statements
@@ -79,10 +99,10 @@ func (w *Workspace) handleFileWatcherEvent(ctx context.Context, client db_common
 			w.onFileWatcherEventMessages()
 		}
 	}
-	w.raiseDashboardChangedEvents(resourceMaps, prevResourceMaps)
+	w.raiseDashboardChangedEvents(ctx, resourceMaps, prevResourceMaps)
 }
 
-func (w *Workspace) reloadResourceMaps(ctx context.Context) (*modconfig.ResourceMaps, *modconfig.ResourceMaps, error) {
+func (w *Workspace) reloadResourceMaps(ctx context.Context) (*modconfig.ResourceMaps, *modconfig.ResourceMaps, *modconfig.ErrorAndWarnings) {
 	w.loadLock.Lock()
 	defer w.loadLock.Unlock()
 
@@ -95,29 +115,27 @@ func (w *Workspace) reloadResourceMaps(ctx context.Context) (*modconfig.Resource
 	}
 
 	// now reload the workspace
-	err := w.loadWorkspaceMod(ctx)
-	if err != nil {
+	errAndWarnings := w.loadWorkspaceMod(ctx)
+	if errAndWarnings.GetError() != nil {
 		// check the existing watcher error - if we are already in an error state, do not show error
 		if w.watcherError == nil {
-			w.fileWatcherErrorHandler(ctx, error_helpers.PrefixError(err, "failed to reload workspace"))
+			w.fileWatcherErrorHandler(ctx, error_helpers.PrefixError(errAndWarnings.GetError(), "failed to reload workspace"))
 		}
 		// now set watcher error to new error
-		w.watcherError = err
-
-		return nil, nil, err
+		w.watcherError = errAndWarnings.GetError()
+		return nil, nil, errAndWarnings
 	}
-
 	// clear watcher error
 	w.watcherError = nil
 
 	// reload the resource maps
 	resourceMaps := w.Mod.ResourceMaps
 
-	return prevResourceMaps, resourceMaps, nil
+	return prevResourceMaps, resourceMaps, errAndWarnings
 
 }
 
-func (w *Workspace) raiseDashboardChangedEvents(resourceMaps, prevResourceMaps *modconfig.ResourceMaps) {
+func (w *Workspace) raiseDashboardChangedEvents(ctx context.Context, resourceMaps, prevResourceMaps *modconfig.ResourceMaps) {
 	event := &dashboardevents.DashboardChanged{}
 
 	// TODO reports can we use a ResourceMaps diff function to do all of this - we are duplicating logic
@@ -223,6 +241,26 @@ func (w *Workspace) raiseDashboardChangedEvents(resourceMaps, prevResourceMaps *
 			event.DeletedImages = append(event.DeletedImages, prev)
 		}
 	}
+	for name, prev := range prevResourceMaps.DashboardNodes {
+		if current, ok := resourceMaps.DashboardNodes[name]; ok {
+			diff := prev.Diff(current)
+			if diff.HasChanges() {
+				event.ChangedNodes = append(event.ChangedNodes, diff)
+			}
+		} else {
+			event.DeletedNodes = append(event.DeletedNodes, prev)
+		}
+	}
+	for name, prev := range prevResourceMaps.DashboardEdges {
+		if current, ok := resourceMaps.DashboardEdges[name]; ok {
+			diff := prev.Diff(current)
+			if diff.HasChanges() {
+				event.ChangedEdges = append(event.ChangedEdges, diff)
+			}
+		} else {
+			event.DeletedEdges = append(event.DeletedEdges, prev)
+		}
+	}
 	for name, prev := range prevResourceMaps.GlobalDashboardInputs {
 		if current, ok := resourceMaps.GlobalDashboardInputs[name]; ok {
 			diff := prev.Diff(current)
@@ -338,6 +376,16 @@ func (w *Workspace) raiseDashboardChangedEvents(resourceMaps, prevResourceMaps *
 			event.NewImages = append(event.NewImages, p)
 		}
 	}
+	for name, p := range resourceMaps.DashboardNodes {
+		if _, ok := prevResourceMaps.DashboardNodes[name]; !ok {
+			event.NewNodes = append(event.NewNodes, p)
+		}
+	}
+	for name, p := range resourceMaps.DashboardEdges {
+		if _, ok := prevResourceMaps.DashboardEdges[name]; !ok {
+			event.NewEdges = append(event.NewEdges, p)
+		}
+	}
 	for name, p := range resourceMaps.GlobalDashboardInputs {
 		if _, ok := prevResourceMaps.GlobalDashboardInputs[name]; !ok {
 			event.NewInputs = append(event.NewInputs, p)
@@ -377,6 +425,6 @@ func (w *Workspace) raiseDashboardChangedEvents(resourceMaps, prevResourceMaps *
 			return true, nil
 		}
 		event.WalkChangedResources(f)
-		w.PublishDashboardEvent(event)
+		w.PublishDashboardEvent(ctx, event)
 	}
 }
