@@ -6,31 +6,32 @@ import isNumber from "lodash/isNumber";
 import isObject from "lodash/isObject";
 import LoadingIndicator from "../LoadingIndicator";
 import useDeepCompareEffect from "use-deep-compare-effect";
+import useTemplateRender from "../../../hooks/useTemplateRender";
 import {
   BasePrimitiveProps,
   ExecutablePrimitiveProps,
   LeafNodeData,
 } from "../common";
 import { classNames } from "../../../utils/styles";
-import { DashboardDataModeLive } from "../../../types";
+import { DashboardDataModeLive, PanelProperties } from "../../../types";
+import { getComponent, registerComponent } from "../index";
 import {
   getIconClasses,
+  getIconForType,
   getTextClasses,
   getWrapperClasses,
 } from "../../../utils/card";
-import { getComponent, registerComponent } from "../index";
 import { isRelativeUrl } from "../../../utils/url";
-import { renderInterpolatedTemplates } from "../../../utils/template";
 import { ThemeNames } from "../../../hooks/useTheme";
 import { useDashboard } from "../../../hooks/useDashboard";
 import { useEffect, useState } from "react";
-import { usePanel } from "../../../hooks/usePanel";
 
 const Table = getComponent("table");
 
-type CardType = "alert" | "info" | "ok" | "table" | null;
+export type CardType = "alert" | "info" | "ok" | "table" | null;
 
-export type CardProps = BasePrimitiveProps &
+export type CardProps = PanelProperties &
+  Omit<BasePrimitiveProps, "display_type"> &
   ExecutablePrimitiveProps & {
     display_type?: CardType;
     properties: {
@@ -43,14 +44,14 @@ export type CardProps = BasePrimitiveProps &
 
 type CardDataFormat = "simple" | "formal";
 
-interface CardState {
+type CardState = {
   loading: boolean;
   label: string | null;
   value: any | null;
   type: CardType;
   icon: string | null;
   href: string | null;
-}
+};
 
 const getDataFormat = (data: LeafNodeData): CardDataFormat => {
   if (data.columns.length > 1) {
@@ -59,32 +60,14 @@ const getDataFormat = (data: LeafNodeData): CardDataFormat => {
   return "simple";
 };
 
-const getIconForType = (type, icon) => {
-  if (!type && !icon) {
-    return null;
-  }
-
-  if (icon) {
-    return icon;
-  }
-
-  switch (type) {
-    case "alert":
-      return "heroicons-solid:exclamation-circle";
-    case "ok":
-      return "heroicons-solid:check-circle";
-    case "info":
-      return "heroicons-solid:information-circle";
-    case "severity":
-      return "heroicons-solid:exclamation";
-    default:
-      return null;
-  }
-};
-
-const useCardState = ({ data, sql, display_type, properties }: CardProps) => {
+const useCardState = ({
+  data,
+  display_type,
+  properties,
+  status,
+}: CardProps) => {
   const [calculatedProperties, setCalculatedProperties] = useState<CardState>({
-    loading: !!sql,
+    loading: status === "running",
     label: properties.label || null,
     value: isNumber(properties.value)
       ? properties.value
@@ -95,18 +78,15 @@ const useCardState = ({ data, sql, display_type, properties }: CardProps) => {
   });
 
   useEffect(() => {
-    if (!data) {
-      return;
-    }
-
     if (
+      !data ||
       !data.columns ||
       !data.rows ||
       data.columns.length === 0 ||
       data.rows.length === 0
     ) {
       setCalculatedProperties({
-        loading: false,
+        loading: status === "running",
         label: properties.label || null,
         value: isNumber(properties.value)
           ? properties.value
@@ -149,7 +129,7 @@ const useCardState = ({ data, sql, display_type, properties }: CardProps) => {
         href: formalHref || properties.href || null,
       });
     }
-  }, [data, display_type, properties]);
+  }, [data, display_type, properties, status]);
 
   return calculatedProperties;
 };
@@ -177,14 +157,10 @@ const Card = (props: CardProps) => {
     state.href || null
   );
   const textClasses = getTextClasses(state.type);
-  const { setZoomIconClassName } = usePanel();
   const {
     themeContext: { theme },
   } = useDashboard();
-
-  useEffect(() => {
-    setZoomIconClassName(textClasses ? textClasses : "");
-  }, [setZoomIconClassName, textClasses]);
+  const { ready: templateRenderReady, renderTemplates } = useTemplateRender();
 
   useEffect(() => {
     if ((state.loading || !state.href) && (renderError || renderedHref)) {
@@ -194,7 +170,7 @@ const Card = (props: CardProps) => {
   }, [state.loading, state.href, renderError, renderedHref]);
 
   useDeepCompareEffect(() => {
-    if (state.loading || !state.href) {
+    if (!templateRenderReady || state.loading || !state.href) {
       return;
     }
     // const { label, loading, value, ...rest } = state;
@@ -209,7 +185,7 @@ const Card = (props: CardProps) => {
     }
 
     const doRender = async () => {
-      const renderedResults = await renderInterpolatedTemplates(
+      const renderedResults = await renderTemplates(
         { card: state.href as string },
         [renderData]
       );
@@ -237,13 +213,7 @@ const Card = (props: CardProps) => {
       }
     };
     doRender();
-  }, [state, props.data]);
-
-  // return (
-  //   <div className="bg-alert text-alert print:bg-white print:border-2 print:border-alert">
-  //     Hello
-  //   </div>
-  // );
+  }, [renderTemplates, templateRenderReady, state, props.data]);
 
   const card = (
     <div
@@ -269,7 +239,10 @@ const Card = (props: CardProps) => {
         >
           {state.loading && "Loading..."}
           {!state.loading && !state.label && (
-            <DashboardIcon className="h-5 w-5" icon="heroicons-solid:minus" />
+            <DashboardIcon
+              className="h-5 w-5"
+              icon="materialsymbols-outline:remove"
+            />
           )}
           {!state.loading && state.label}
         </p>
@@ -301,7 +274,7 @@ const Card = (props: CardProps) => {
             (state.value === null || state.value === undefined) && (
               <DashboardIcon
                 className="h-10 w-10"
-                icon="heroicons-solid:minus"
+                icon="materialsymbols-outline:remove"
               />
             )}
           {state.value !== null &&
