@@ -2,6 +2,7 @@ import ControlDimension from "../check/Benchmark/ControlDimension";
 import isEmpty from "lodash/isEmpty";
 import isObject from "lodash/isObject";
 import useDeepCompareEffect from "use-deep-compare-effect";
+import useTemplateRender from "../../../hooks/useTemplateRender";
 import {
   AlarmIcon,
   InfoIcon,
@@ -17,7 +18,11 @@ import {
   LeafNodeDataRow,
 } from "../common";
 import { classNames } from "../../../utils/styles";
-import { DashboardDataMode, DashboardDataModeLive } from "../../../types";
+import {
+  DashboardDataMode,
+  DashboardDataModeLive,
+  PanelDefinition,
+} from "../../../types";
 import {
   ErrorIcon,
   SortAscendingIcon,
@@ -26,18 +31,14 @@ import {
 import { isRelativeUrl } from "../../../utils/url";
 import { memo, useEffect, useMemo, useState } from "react";
 import { registerComponent } from "../index";
-import {
-  RowRenderResult,
-  renderInterpolatedTemplates,
-} from "../../../utils/template";
-import { ThemeNames } from "../../../hooks/useTheme";
+import { RowRenderResult } from "../common/types";
 import { useDashboard } from "../../../hooks/useDashboard";
 import { useSortBy, useTable } from "react-table";
 
 export type TableColumnDisplay = "all" | "none";
 export type TableColumnWrap = "all" | "none";
 
-interface TableColumnInfo {
+type TableColumnInfo = {
   Header: string;
   accessor: string;
   name: string;
@@ -46,7 +47,7 @@ interface TableColumnInfo {
   wrap: TableColumnWrap;
   href_template?: string;
   sortType?: any;
-}
+};
 
 const getColumns = (
   cols: LeafNodeDataColumn[],
@@ -102,14 +103,14 @@ const getData = (columns: TableColumnInfo[], rows: LeafNodeDataRow[]) => {
   return rows;
 };
 
-interface CellValueProps {
+type CellValueProps = {
   column: TableColumnInfo;
   dataMode: DashboardDataMode;
   rowIndex: number;
   rowTemplateData: RowRenderResult[];
   value: any;
   showTitle?: boolean;
-}
+};
 
 const CellValue = ({
   column,
@@ -351,11 +352,11 @@ const CellValue = ({
 
 const MemoCellValue = memo(CellValue);
 
-interface TableColumnOptions {
+type TableColumnOptions = {
   display?: TableColumnDisplay;
   href?: string;
   wrap?: TableColumnWrap;
-}
+};
 
 type TableColumns = {
   [column: string]: TableColumnOptions;
@@ -367,7 +368,8 @@ export type TableProperties = {
   columns?: TableColumns;
 };
 
-export type TableProps = BasePrimitiveProps &
+export type TableProps = PanelDefinition &
+  BasePrimitiveProps &
   ExecutablePrimitiveProps & {
     display_type?: TableType;
     properties?: TableProperties;
@@ -379,10 +381,8 @@ const TableView = ({
   hiddenColumns,
   hasTopBorder = false,
 }) => {
-  const {
-    dataMode,
-    themeContext: { theme },
-  } = useDashboard();
+  const { dataMode } = useDashboard();
+  const { ready: templateRenderReady, renderTemplates } = useTemplateRender();
   const [rowTemplateData, setRowTemplateData] = useState<RowRenderResult[]>([]);
 
   const { getTableProps, getTableBodyProps, headerGroups, prepareRow, rows } =
@@ -392,6 +392,11 @@ const TableView = ({
     );
 
   useDeepCompareEffect(() => {
+    if (!templateRenderReady || columns.length === 0 || rows.length === 0) {
+      setRowTemplateData([]);
+      return;
+    }
+
     const doRender = async () => {
       const templates = Object.fromEntries(
         columns
@@ -403,20 +408,12 @@ const TableView = ({
         return;
       }
       const data = rows.map((row) => row.values);
-      const renderedResults = await renderInterpolatedTemplates(
-        templates,
-        data
-      );
-      setRowTemplateData(renderedResults);
+      const renderedResults = await renderTemplates(templates, data);
+      setRowTemplateData(renderedResults || []);
     };
 
-    if (columns.length === 0 || rows.length === 0) {
-      setRowTemplateData([]);
-      return;
-    }
-
     doRender();
-  }, [columns, rows]);
+  }, [columns, rows, renderTemplates, templateRenderReady]);
 
   return (
     <>
@@ -424,21 +421,10 @@ const TableView = ({
         {...getTableProps()}
         className={classNames(
           "min-w-full divide-y divide-table-divide overflow-hidden",
-          hasTopBorder
-            ? theme.name === ThemeNames.STEAMPIPE_DARK
-              ? "border-t border-table-divide"
-              : "border-t border-background"
-            : null
+          hasTopBorder ? "border-t border-divide" : null
         )}
       >
-        <thead
-          className={classNames(
-            "text-table-head",
-            theme.name === ThemeNames.STEAMPIPE_DARK
-              ? "border-b border-table-divide"
-              : "border-b border-background"
-          )}
-        >
+        <thead className="text-table-head border-b border-divide">
           {headerGroups.map((headerGroup) => (
             <tr {...headerGroup.getHeaderGroupProps()}>
               {headerGroup.headers.map((column) => (
@@ -491,7 +477,7 @@ const TableView = ({
                       "px-4 py-4 align-top content-center text-sm",
                       isNumericCol(cell.column.data_type) ? "text-right" : "",
                       cell.column.wrap === "all"
-                        ? "break-all"
+                        ? "break-keep"
                         : "whitespace-nowrap"
                     )}
                   >
@@ -536,12 +522,15 @@ const TableViewWrapper = (props: TableProps) => {
 
 const LineView = (props: TableProps) => {
   const { dataMode } = useDashboard();
+  const { ready: templateRenderReady, renderTemplates } = useTemplateRender();
   const [columns, setColumns] = useState<TableColumnInfo[]>([]);
   const [rows, setRows] = useState<LeafNodeDataRow[]>([]);
   const [rowTemplateData, setRowTemplateData] = useState<RowRenderResult[]>([]);
 
   useEffect(() => {
     if (!props.data || !props.data.columns || !props.data.rows) {
+      setColumns([]);
+      setRows([]);
       return;
     }
     const newColumns: TableColumnInfo[] = [];
@@ -559,20 +548,16 @@ const LineView = (props: TableProps) => {
       newColumns.push(newColDef);
     });
 
-    // const newRows: LineModeRows[] = [];
-    // props.data.rows.forEach((row) => {
-    //   const rowObj = {};
-    //   newColumns.forEach((col, index) => {
-    //     rowObj[col.name] = row[index];
-    //   });
-    //   newRows.push({ row, obj: rowObj });
-    // });
-
     setColumns(newColumns);
     setRows(props.data.rows);
   }, [props.data, props.properties]);
 
   useDeepCompareEffect(() => {
+    if (!templateRenderReady || columns.length === 0 || rows.length === 0) {
+      setRowTemplateData([]);
+      return;
+    }
+
     const doRender = async () => {
       const templates = Object.fromEntries(
         columns
@@ -584,20 +569,12 @@ const LineView = (props: TableProps) => {
         return;
       }
       const data = rows.map((row) => row.obj);
-      const renderedResults = await renderInterpolatedTemplates(
-        templates,
-        data
-      );
+      const renderedResults = await renderTemplates(templates, data);
       setRowTemplateData(renderedResults);
     };
 
-    if (columns.length === 0 || rows.length === 0) {
-      setRowTemplateData([]);
-      return;
-    }
-
     doRender();
-  }, [columns, rows]);
+  }, [columns, rows, renderTemplates, templateRenderReady]);
 
   if (columns.length === 0 || rows.length === 0) {
     return null;
@@ -620,7 +597,7 @@ const LineView = (props: TableProps) => {
                   <span
                     className={classNames(
                       "block",
-                      col.wrap === "all" ? "break-words" : "truncate"
+                      col.wrap === "all" ? "break-keep" : "truncate"
                     )}
                   >
                     <MemoCellValue
@@ -651,4 +628,6 @@ const Table = (props: TableProps) => {
 
 registerComponent("table", Table);
 
+export default Table;
+
 export { TableView };
