@@ -6,53 +6,52 @@ import {
   Edge,
   EdgeMap,
   KeyValuePairs,
-  KeyValueStringPairs,
   Node,
-  NodeAndEdgeProperties,
   NodeCategoryMap,
   NodeMap,
   NodesAndEdges,
 } from "./types";
 import { ChartProperties, ChartTransform, ChartType } from "../charts/types";
-import { DashboardRunState, PanelsMap } from "../../../types";
+import { DashboardRunState } from "../../../types";
+import { ExpandedNodes } from "../graphs/common/useGraph";
 import { FlowProperties, FlowType } from "../flows/types";
 import { getColumn } from "../../../utils/data";
-import { getNodeAndEdgeDataFormat } from "./useNodeAndEdgeData";
 import { Graph, json } from "graphlib";
 import { GraphProperties, GraphType, NodeAndEdgeData } from "../graphs/types";
 import { HierarchyProperties, HierarchyType } from "../hierarchies/types";
 
 export type Width = 0 | 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 | 11 | 12;
 
-export interface BasePrimitiveProps {
+export type BasePrimitiveProps = {
   base?: string;
+  dashboard: string;
   name: string;
   panel_type: string;
   display_type?: string;
   title?: string;
   width?: Width;
-}
+};
 
-export interface LeafNodeDataColumn {
+export type LeafNodeDataColumn = {
   name: string;
   data_type: string;
-}
+};
 
-export interface LeafNodeDataRow {
+export type LeafNodeDataRow = {
   [key: string]: any;
-}
+};
 
-export interface LeafNodeData {
+export type LeafNodeData = {
   columns: LeafNodeDataColumn[];
   rows: LeafNodeDataRow[];
-}
+};
 
-export interface ExecutablePrimitiveProps {
+export type ExecutablePrimitiveProps = {
   sql?: string;
   data?: LeafNodeData;
   error?: Error;
   status: DashboardRunState;
-}
+};
 
 export type ColorOverride = "alert" | "info" | "ok" | string;
 
@@ -72,11 +71,11 @@ const toEChartsType = (
   return type as EChartsType;
 };
 
-interface ChartDatasetResponse {
+type ChartDatasetResponse = {
   dataset: any[][];
   rowSeriesLabels: string[];
   transform: ChartTransform;
-}
+};
 
 const crosstabDataTransform = (data: LeafNodeData): ChartDatasetResponse => {
   if (data.columns.length < 3) {
@@ -271,6 +270,7 @@ const recordEdge = (
     title,
     category,
     row_data,
+    isFolded: false,
   };
 
   if (existingNode) {
@@ -341,7 +341,7 @@ const getCategoriesWithFold = (categories: CategoryMap): CategoryMap => {
 
 const foldNodesAndEdges = (
   nodesAndEdges: NodesAndEdges,
-  expandedNodes: KeyValueStringPairs = {}
+  expandedNodes: ExpandedNodes = {}
 ): NodesAndEdges => {
   const categoriesWithFold = getCategoriesWithFold(nodesAndEdges.categories);
 
@@ -529,12 +529,14 @@ const foldNodesAndEdges = (
         // Add the source edges back to the folded node
         for (const sourceNode of groupingInfo.source) {
           graph.setEdge(sourceNode, foldedNode.id);
-          const edge = {
+          const edge: Edge = {
             id: `${sourceNode}_${foldedNode.id}`,
             from_id: sourceNode,
             to_id: foldedNode.id,
             category: sourceEdgeCategory,
             title: sourceEdgeTitle,
+            isFolded: true,
+            row_data: null,
           };
           newNodesAndEdges.edgeMap[edge.id] = edge;
         }
@@ -583,6 +585,7 @@ const foldNodesAndEdges = (
 };
 
 const buildNodesAndEdges = (
+  categories: CategoryMap = {},
   rawData: NodeAndEdgeData | undefined,
   properties: FlowProperties | GraphProperties | HierarchyProperties = {},
   namedThemeColors = {},
@@ -633,27 +636,33 @@ const buildNodesAndEdges = (
   const edge_lookup: EdgeMap = {};
   const nodes: Node[] = [];
   const edges: Edge[] = [];
-  const categories: CategoryMap = {};
 
   let contains_duplicate_edges = false;
   let colorIndex = 0;
 
   rawData.rows.forEach((row) => {
-    const node_id: string | null = row.id || null;
-    const from_id: string | null = row.from_id || null;
-    const to_id: string | null = row.to_id || null;
+    const node_id: string | null =
+      has(row, "id") && row.id !== null && row.id !== undefined
+        ? row.id.toString()
+        : null;
+    const from_id: string | null =
+      has(row, "from_id") && row.from_id !== null && row.from_id !== undefined
+        ? row.from_id.toString()
+        : null;
+    const to_id: string | null =
+      has(row, "to_id") && row.to_id !== null && row.to_id !== undefined
+        ? row.to_id.toString()
+        : null;
     const title: string | null = row.title || null;
     const category: string | null = row.category || null;
-    const depth: number | null = row.depth || null;
+    const depth: number | null =
+      typeof row.depth === "number" ? row.depth : null;
 
     if (category && !categories[category]) {
       const overrides = categoryProperties[category];
       const categorySettings: Category = {};
       if (overrides) {
-        const overrideColor = getColorOverride(
-          overrides.color,
-          namedThemeColors
-        );
+        const overrideColor = overrides.color;
         // @ts-ignore
         categorySettings.color = overrideColor
           ? overrideColor
@@ -684,7 +693,7 @@ const buildNodesAndEdges = (
       categories[category] = categorySettings;
     }
 
-    // 4 types of row:
+    // 5 types of row:
     //
     // id                  = node         1      1
     // from_id & id        = node & edge  1 2    3
@@ -708,6 +717,7 @@ const buildNodesAndEdges = (
     // If this row is a node
     if (!!node_id) {
       const existingNode = node_lookup[node_id];
+
       // Even if the node already existed, it will only have minimal info, as it
       // could only have been created implicitly through an edge definition, so
       // build a full node and update it
@@ -722,7 +732,16 @@ const buildNodesAndEdges = (
         categories
       );
 
-      if (!existingNode) {
+      // Ensure that any existing references to this node are also updated
+      if (existingNode) {
+        const nodeIndex = nodes.findIndex((n) => n.id === node.id);
+        if (nodeIndex >= 0) {
+          nodes[nodeIndex] = node;
+        }
+        if (root_node_lookup[node.id]) {
+          root_node_lookup[node.id] = node;
+        }
+      } else {
         graph.setNode(node_id);
         nodes.push(node);
 
@@ -938,13 +957,13 @@ const buildSankeyDataInputs = (nodesAndEdges: NodesAndEdges) => {
   };
 };
 
-interface Item {
+type Item = {
   [key: string]: any;
-}
+};
 
-interface TreeItem {
+type TreeItem = {
   [key: string]: Item | TreeItem[] | any;
-}
+};
 
 // Taken from https://github.com/philipstanislaus/performant-array-to-tree
 const nodesAndEdgesToTree = (nodesAndEdges: NodesAndEdges): TreeItem[] => {
@@ -1073,28 +1092,6 @@ const getColorOverride = (colorOverride, namedThemeColors) => {
   return colorOverride;
 };
 
-const nodeAndEdgeResourceHasData = (
-  data: LeafNodeData,
-  properties: NodeAndEdgeProperties,
-  panelsMap: PanelsMap
-): boolean => {
-  const dataFormat = getNodeAndEdgeDataFormat(properties);
-  if (dataFormat === "LEGACY" && !!data) {
-    return true;
-  }
-  if (dataFormat === "LEGACY" && !data) {
-    return false;
-  }
-  if (
-    (properties?.nodes || []).some((p) => panelsMap[p] && !!panelsMap[p].data)
-  ) {
-    return true;
-  }
-  return (properties?.edges || []).some(
-    (p) => panelsMap[p] && !!panelsMap[p].data
-  );
-};
-
 export {
   adjustMinValue,
   adjustMaxValue,
@@ -1105,7 +1102,6 @@ export {
   foldNodesAndEdges,
   getColorOverride,
   isNumericCol,
-  nodeAndEdgeResourceHasData,
   themeColors,
   toEChartsType,
 };
