@@ -1,21 +1,25 @@
 import { BasePrimitiveProps, ExecutablePrimitiveProps } from "../common";
 import { ComponentType } from "react";
-import { NodeAndEdgeProperties } from "../common/types";
+import { CategoryMap, NodeAndEdgeProperties } from "../common/types";
 import { NodeAndEdgeData } from "../graphs/types";
+import { PanelDefinition } from "../../../types";
 
-export type BaseHierarchyProps = BasePrimitiveProps & ExecutablePrimitiveProps;
+export type BaseHierarchyProps = PanelDefinition &
+  BasePrimitiveProps &
+  ExecutablePrimitiveProps;
 
 export type HierarchyProperties = NodeAndEdgeProperties;
 
-export interface HierarchyProps extends BaseHierarchyProps {
+export type HierarchyProps = BaseHierarchyProps & {
+  categories: CategoryMap;
   data?: NodeAndEdgeData;
   display_type?: HierarchyType;
   properties?: NodeAndEdgeProperties;
-}
+};
 
 export type HierarchyType = "table" | "tree";
 
-export interface IHierarchy {
+export type IHierarchy = {
   type: HierarchyType;
   component: ComponentType<any>;
-}
+};
