@@ -7,12 +7,6 @@ import ControlRunningNode from "../components/dashboards/check/common/node/Contr
 import KeyValuePairNode from "../components/dashboards/check/common/node/KeyValuePairNode";
 import RootNode from "../components/dashboards/check/common/node/RootNode";
 import usePrevious from "./usePrevious";
-import {
-  BenchmarkDefinition,
-  ElementType,
-  IActions,
-  PanelDefinition,
-} from "../types";
 import {
   CheckDisplayGroup,
   CheckDisplayGroupType,
@@ -29,25 +23,26 @@ import {
   useReducer,
 } from "react";
 import { default as BenchmarkType } from "../components/dashboards/check/common/Benchmark";
+import { ElementType, IActions, PanelDefinition } from "../types";
 import { useDashboard } from "./useDashboard";
 import { useSearchParams } from "react-router-dom";
 
 type CheckGroupingActionType = ElementType<typeof checkGroupingActions>;
 
-export interface CheckGroupNodeState {
+export type CheckGroupNodeState = {
   expanded: boolean;
-}
+};
 
-export interface CheckGroupNodeStates {
+export type CheckGroupNodeStates = {
   [name: string]: CheckGroupNodeState;
-}
+};
 
-export interface CheckGroupingAction {
+export type CheckGroupingAction = {
   type: CheckGroupingActionType;
   [key: string]: any;
-}
+};
 
-interface ICheckGroupingContext {
+type ICheckGroupingContext = {
   benchmark: BenchmarkType | null;
   definition: PanelDefinition;
   grouping: CheckNode | null;
@@ -55,7 +50,7 @@ interface ICheckGroupingContext {
   firstChildSummaries: CheckSummary[];
   nodeStates: CheckGroupNodeStates;
   dispatch(action: CheckGroupingAction): void;
-}
+};
 
 const CheckGroupingActions: IActions = {
   COLLAPSE_ALL_NODES: "collapse_all_nodes",
@@ -355,10 +350,10 @@ const reducer = (state: CheckGroupNodeStates, action) => {
   }
 };
 
-interface CheckGroupingProviderProps {
+type CheckGroupingProviderProps = {
   children: null | JSX.Element | JSX.Element[];
-  definition: BenchmarkDefinition;
-}
+  definition: PanelDefinition;
+};
 
 const CheckGroupingProvider = ({
   children,
@@ -534,5 +529,3 @@ export {
 //     return r[a[k]];
 //   }, temp)._.push({ Id: a.Id });
 // });
-//
-// console.log(result);
